@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -37,8 +37,8 @@
 
 #include "shareableobject.h"
 #include "file/nfilepropertyreader.h"
+#include "maths/nrational.h"
 #include "maths/nray.h"
-#include "utilities/nrational.h"
 
 namespace regina {
 
