@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -44,22 +44,12 @@ const unsigned NClosedPrimeMinSearcher::EDGE_DOUBLE_FIRST = 4;
 const unsigned NClosedPrimeMinSearcher::EDGE_DOUBLE_SECOND = 5;
 const unsigned NClosedPrimeMinSearcher::EDGE_MISC = 6;
 
-const char NClosedPrimeMinSearcher::VLINK_CLOSED = 1;
-const char NClosedPrimeMinSearcher::VLINK_NON_SPHERE = 2;
-
 const char NClosedPrimeMinSearcher::ECLASS_TWISTED = 1;
 const char NClosedPrimeMinSearcher::ECLASS_LOWDEG = 2;
 const char NClosedPrimeMinSearcher::ECLASS_HIGHDEG = 4;
 const char NClosedPrimeMinSearcher::ECLASS_CONE = 8;
 const char NClosedPrimeMinSearcher::ECLASS_L31 = 16;
 
-const int NClosedPrimeMinSearcher::vertexLinkNextFace[4][4] = {
-    { -1, 2, 3, 1},
-    { 3, -1, 0, 2},
-    { 1, 3, -1, 0},
-    { 1, 2, 0, -1}
-};
-
 const unsigned NClosedPrimeMinSearcher::coneEdge[12][2] = {
     { 0, 1 }, { 0, 2 }, { 1, 2 }, { 0, 3 }, { 0, 4 }, { 3, 4 },
     { 1, 3 }, { 1, 5 }, { 3, 5 }, { 2, 4 }, { 2, 5 }, { 4, 5 },
@@ -71,132 +61,20 @@ const char NClosedPrimeMinSearcher::coneNoTwist[12] = {
 
 const char NClosedPrimeMinSearcher::dataTag_ = 'c';
 
-void NClosedPrimeMinSearcher::TetVertexState::dumpData(std::ostream& out)
-        const {
-    // Be careful with twistUp, which is a char but which should be
-    // written as an int.
-    out << parent << ' ' << rank << ' ' << bdry << ' '
-        << (twistUp ? 1 : 0) << ' ' << (hadEqualRank ? 1 : 0) << ' '
-        << static_cast<int>(bdryEdges) << ' '
-        << bdryNext[0] << ' ' << bdryNext[1] << ' '
-        << static_cast<int>(bdryTwist[0]) << ' '
-        << static_cast<int>(bdryTwist[1]) << ' '
-        << bdryNextOld[0] << ' ' << bdryNextOld[1] << ' '
-        << static_cast<int>(bdryTwistOld[0]) << ' '
-        << static_cast<int>(bdryTwistOld[1]);
-}
-
-bool NClosedPrimeMinSearcher::TetVertexState::readData(std::istream& in,
-        unsigned long nStates) {
-    in >> parent >> rank >> bdry;
-
-    // twistUp is a char, but we need to read it as an int.
-    int twist;
-    in >> twist;
-    twistUp = twist;
-
-    // hadEqualRank is a bool, but we need to read it as an int.
-    int bRank;
-    in >> bRank;
-    hadEqualRank = bRank;
-
-    // More chars to ints coming.
-    int bVal;
-
-    in >> bVal; bdryEdges = bVal;
-    in >> bdryNext[0] >> bdryNext[1];
-    in >> bVal; bdryTwist[0] = bVal;
-    in >> bVal; bdryTwist[1] = bVal;
-    in >> bdryNextOld[0] >> bdryNextOld[1];
-    in >> bVal; bdryTwistOld[0] = bVal;
-    in >> bVal; bdryTwistOld[1] = bVal;
-
-    if (parent < -1 || parent >= static_cast<long>(nStates))
-        return false;
-    if (rank >= nStates)
-        return false;
-    if (bdry > 3 * nStates)
-        return false;
-    if (twist != 1 && twist != 0)
-        return false;
-    if (bRank != 1 && bRank != 0)
-        return false;
-    if (bdryEdges > 3) /* Never < 0 since this is unsigned. */
-        return false;
-    if (bdryNext[0] < 0 || bdryNext[0] >= static_cast<long>(nStates))
-        return false;
-    if (bdryNext[1] < 0 || bdryNext[1] >= static_cast<long>(nStates))
-        return false;
-    if (bdryNextOld[0] < -1 || bdryNext[0] >= static_cast<long>(nStates))
-        return false;
-    if (bdryNextOld[1] < -1 || bdryNextOld[1] >= static_cast<long>(nStates))
-        return false;
-    if (bdryTwist[0] < 0 || bdryTwist[0] > 1)
-        return false;
-    if (bdryTwist[1] < 0 || bdryTwist[1] > 1)
-        return false;
-    if (bdryTwistOld[0] < 0 || bdryTwistOld[0] > 1)
-        return false;
-    if (bdryTwistOld[1] < 0 || bdryTwistOld[1] > 1)
-        return false;
-
-    return true;
-}
-
-void NClosedPrimeMinSearcher::TetEdgeState::dumpData(std::ostream& out) const {
-    // Be careful with twistUp, which is a char but which should be
-    // written as an int.
-    out << parent << ' ' << rank << ' ' << size << ' '
-        << (bounded ? 1 : 0) << ' ' << (twistUp ? 1 : 0) << ' '
-        << (hadEqualRank ? 1 : 0);
-}
-
-bool NClosedPrimeMinSearcher::TetEdgeState::readData(std::istream& in,
-        unsigned long nStates) {
-    in >> parent >> rank >> size;
-
-    // bounded is a bool, but we need to read it as an int.
-    int bBounded;
-    in >> bBounded;
-    bounded = bBounded;
-
-    // twistUp is a char, but we need to read it as an int.
-    int twist;
-    in >> twist;
-    twistUp = twist;
-
-    // hadEqualRank is a bool, but we need to read it as an int.
-    int bRank;
-    in >> bRank;
-    hadEqualRank = bRank;
-
-    if (parent < -1 || parent >= static_cast<long>(nStates))
-        return false;
-    if (rank >= nStates)
-        return false;
-    if (size >= nStates)
-        return false;
-    if (bBounded != 1 && bBounded != 0)
-        return false;
-    if (twist != 1 && twist != 0)
-        return false;
-    if (bRank != 1 && bRank != 0)
-        return false;
-
-    return true;
-}
-
 NClosedPrimeMinSearcher::NClosedPrimeMinSearcher(const NFacePairing* pairing,
         const NFacePairingIsoList* autos, bool orientableOnly,
         UseGluingPerms use, void* useArgs) :
-        NGluingPermSearcher(pairing, autos, orientableOnly,
-            true /* finiteOnly */,
+        NCompactSearcher(pairing, autos, orientableOnly,
             NCensus::PURGE_NON_MINIMAL_PRIME | NCensus::PURGE_P2_REDUCIBLE,
             use, useArgs) {
-    initOrder();
-}
+    // Initialise internal arrays, specifically those relating to face
+    // orderings and properties of chains, to accurately reflect the
+    // underlying face pairing.
+    //
+    // Although the NGluingPermSearcher constructor initialises the order[]
+    // array in a vanilla fashion (front to back), we reorder things now
+    // to match specific structures that are found in the face pairing graph.
 
-void NClosedPrimeMinSearcher::initOrder() {
     // Preconditions:
     //     Only closed prime minimal P2-irreducible triangulations are needed.
     //     The given face pairing is closed with order >= 3.
@@ -217,7 +95,6 @@ void NClosedPrimeMinSearcher::initOrder() {
 
     unsigned nTets = getNumberOfTetrahedra();
 
-    order = new NTetFace[nTets * 2];
     orderType = new unsigned[nTets * 2];
 
     bool* orderAssigned = new bool[nTets * 4];
@@ -423,25 +300,6 @@ void NClosedPrimeMinSearcher::initOrder() {
 
     // ---------- Tracking of vertex / edge equivalence classes ----------
 
-    nVertexClasses = nTets * 4;
-    vertexState = new TetVertexState[nTets * 4];
-    vertexStateChanged = new int[nTets * 8];
-    std::fill(vertexStateChanged, vertexStateChanged + nTets * 8, -1);
-    for (i = 0; i < nTets * 4; i++) {
-        vertexState[i].bdryEdges = 3;
-        vertexState[i].bdryNext[0] = vertexState[i].bdryNext[1] = i;
-        vertexState[i].bdryTwist[0] = vertexState[i].bdryTwist[1] = 0;
-        // Initialise the backup members also so we're not writing
-        // uninitialised data via dumpData().
-        vertexState[i].bdryNextOld[0] = vertexState[i].bdryNextOld[1] = -1;
-        vertexState[i].bdryTwistOld[0] = vertexState[i].bdryTwistOld[1] = 0;
-    }
-
-    nEdgeClasses = nTets * 6;
-    edgeState = new TetEdgeState[nTets * 6];
-    edgeStateChanged = new int[nTets * 8];
-    std::fill(edgeStateChanged, edgeStateChanged + nTets * 8, -1);
-
 #if PRUNE_HIGH_DEG_EDGE_SET
     highDegSum = 0;
     highDegBound = 3 * nTets - 3;
@@ -546,7 +404,7 @@ void NClosedPrimeMinSearcher::runSearch(long maxDepth) {
 
             // Be sure to preserve the orientation of the permutation if
             // necessary.
-            if ((! orientableOnly_) || pairing->dest(face).face == 0)
+            if ((! orientableOnly_) || adj.face == 0)
                 permIndex(face)++;
             else
                 permIndex(face) += 2;
@@ -569,7 +427,7 @@ void NClosedPrimeMinSearcher::runSearch(long maxDepth) {
         }
 
         // We are sitting on a new permutation to try.
-        permIndex(adj) = allPermsS3Inv[permIndex(face)];
+        permIndex(adj) = NPerm::invS3[permIndex(face)];
 
         // In the following code we use several results from
         // "Face pairing graphs and 3-manifold enumeration", B. A. Burton,
@@ -802,21 +660,19 @@ void NClosedPrimeMinSearcher::runSearch(long maxDepth) {
 }
 
 void NClosedPrimeMinSearcher::dumpData(std::ostream& out) const {
-    NGluingPermSearcher::dumpData(out);
+    NCompactSearcher::dumpData(out);
 
-    unsigned nTets = getNumberOfTetrahedra();
-    unsigned i;
-
-    for (i = 0; i < 2 * nTets; i++) {
+    int i;
+    for (i = 0; i < orderSize; i++) {
         if (i)
             out << ' ';
-        out << order[i].tet << ' ' << order[i].face << ' ' << orderType[i];
+        out << orderType[i];
     }
     out << std::endl;
 
     out << nChainEdges << std::endl;
     if (nChainEdges) {
-        for (i = 0; i < 2 * nChainEdges; i++) {
+        for (i = 0; i < 2 * static_cast<int>(nChainEdges); i++) {
             if (i)
                 out << ' ';
             out << chainPermIndices[i];
@@ -824,32 +680,6 @@ void NClosedPrimeMinSearcher::dumpData(std::ostream& out) const {
         out << std::endl;
     }
 
-    out << orderElt << std::endl;
-
-    out << nVertexClasses << std::endl;
-    for (i = 0; i < 4 * nTets; i++) {
-        vertexState[i].dumpData(out);
-        out << std::endl;
-    }
-    for (i = 0; i < 8 * nTets; i++) {
-        if (i)
-            out << ' ';
-        out << vertexStateChanged[i];
-    }
-    out << std::endl;
-
-    out << nEdgeClasses << std::endl;
-    for (i = 0; i < 6 * nTets; i++) {
-        edgeState[i].dumpData(out);
-        out << std::endl;
-    }
-    for (i = 0; i < 8 * nTets; i++) {
-        if (i)
-            out << ' ';
-        out << edgeStateChanged[i];
-    }
-    out << std::endl;
-
 #if PRUNE_HIGH_DEG_EDGE_SET
     out << highDegSum << ' ' << highDegBound << std::endl;
 #endif
@@ -857,26 +687,17 @@ void NClosedPrimeMinSearcher::dumpData(std::ostream& out) const {
 
 NClosedPrimeMinSearcher::NClosedPrimeMinSearcher(std::istream& in,
         UseGluingPerms use, void* useArgs) :
-        NGluingPermSearcher(in, use, useArgs),
-        order(0), orderType(0), nChainEdges(0), chainPermIndices(0),
-        nVertexClasses(0), vertexState(0), vertexStateChanged(0),
-        nEdgeClasses(0), edgeState(0), edgeStateChanged(0),
-        orderElt(0) {
+        NCompactSearcher(in, use, useArgs),
+        orderType(0), nChainEdges(0), chainPermIndices(0) {
     if (inputError_)
         return;
 
     unsigned nTets = getNumberOfTetrahedra();
-    unsigned i;
+    int i;
 
-    order = new NTetFace[2 * nTets];
-    orderType = new unsigned[nTets * 2];
-    for (i = 0; i < 2 * nTets; i++) {
-        in >> order[i].tet >> order[i].face >> orderType[i];
-        if (order[i].tet >= static_cast<int>(nTets) || order[i].tet < 0 ||
-                order[i].face >= 4 || order[i].face < 0) {
-            inputError_ = true; return;
-        }
-    }
+    orderType = new unsigned[2 * nTets];
+    for (i = 0; i < orderSize; i++)
+        in >> orderType[i];
 
     in >> nChainEdges;
     /* Unnecessary since nChainEdges is unsigned.
@@ -885,7 +706,7 @@ NClosedPrimeMinSearcher::NClosedPrimeMinSearcher(std::istream& in,
     } */
     if (nChainEdges) {
         chainPermIndices = new int[nChainEdges * 2];
-        for (i = 0; i < 2 * nChainEdges; i++) {
+        for (i = 0; i < 2 * static_cast<int>(nChainEdges); i++) {
             in >> chainPermIndices[i];
             if (chainPermIndices[i] < 0 || chainPermIndices[i] >= 6) {
                 inputError_ = true; return;
@@ -893,48 +714,6 @@ NClosedPrimeMinSearcher::NClosedPrimeMinSearcher(std::istream& in,
         }
     }
 
-    in >> orderElt;
-
-    in >> nVertexClasses;
-    if (nVertexClasses > 4 * nTets) {
-        inputError_ = true; return;
-    }
-
-    vertexState = new TetVertexState[4 * nTets];
-    for (i = 0; i < 4 * nTets; i++)
-        if (! vertexState[i].readData(in, 4 * nTets)) {
-            inputError_ = true; return;
-        }
-
-    vertexStateChanged = new int[8 * nTets];
-    for (i = 0; i < 8 * nTets; i++) {
-        in >> vertexStateChanged[i];
-        if (vertexStateChanged[i] < -1 ||
-                 vertexStateChanged[i] >= 4 * static_cast<int>(nTets)) {
-            inputError_ = true; return;
-        }
-    }
-
-    in >> nEdgeClasses;
-    if (nEdgeClasses > 6 * nTets) {
-        inputError_ = true; return;
-    }
-
-    edgeState = new TetEdgeState[6 * nTets];
-    for (i = 0; i < 6 * nTets; i++)
-        if (! edgeState[i].readData(in, 6 * nTets)) {
-            inputError_ = true; return;
-        }
-
-    edgeStateChanged = new int[8 * nTets];
-    for (i = 0; i < 8 * nTets; i++) {
-        in >> edgeStateChanged[i];
-        if (edgeStateChanged[i] < -1 ||
-                 edgeStateChanged[i] >= 6 * static_cast<int>(nTets)) {
-            inputError_ = true; return;
-        }
-    }
-
 #if PRUNE_HIGH_DEG_EDGE_SET
     in >> highDegSum >> highDegBound;
     if (highDegSum < 0 || highDegSum > 6 * static_cast<int>(nTets) ||
@@ -948,312 +727,6 @@ NClosedPrimeMinSearcher::NClosedPrimeMinSearcher(std::istream& in,
         inputError_ = true;
 }
 
-int NClosedPrimeMinSearcher::mergeVertexClasses() {
-    // Merge all three vertex pairs for the current face.
-    NTetFace face = order[orderElt];
-    NTetFace adj = (*pairing)[face];
-
-    int retVal = 0;
-
-    int v, w;
-    int vIdx, wIdx, tmpIdx, nextIdx;
-    unsigned orderIdx;
-    int vRep, wRep;
-    int vNext[2], wNext[2];
-    char vTwist[2], wTwist[2];
-    NPerm p = gluingPerm(face);
-    char parentTwists, hasTwist, tmpTwist;
-    for (v = 0; v < 4; v++) {
-        if (v == face.face)
-            continue;
-
-        w = p[v];
-        vIdx = v + 4 * face.tet;
-        wIdx = w + 4 * adj.tet;
-        orderIdx = v + 4 * orderElt;
-
-        // Are the natural 012 representations of the two faces joined
-        // with reversed orientations?
-        // Here we combine the sign of permutation p with the mappings
-        // from 012 to the native tetrahedron vertices, i.e., v <-> 3 and
-        // w <-> 3.
-        hasTwist = (p.sign() < 0 ? 0 : 1);
-        if ((v == 3 && w != 3) || (v != 3 && w == 3))
-            hasTwist ^= 1;
-
-        parentTwists = 0;
-        for (vRep = vIdx; vertexState[vRep].parent >= 0;
-                vRep = vertexState[vRep].parent)
-            parentTwists ^= vertexState[vRep].twistUp;
-        for (wRep = wIdx; vertexState[wRep].parent >= 0;
-                wRep = vertexState[wRep].parent)
-            parentTwists ^= vertexState[wRep].twistUp;
-
-        if (vRep == wRep) {
-            vertexState[vRep].bdry -= 2;
-            if (vertexState[vRep].bdry == 0)
-                retVal |= VLINK_CLOSED;
-
-            // Have we made the vertex link non-orientable?
-            if (hasTwist ^ parentTwists)
-                retVal |= VLINK_NON_SPHERE;
-
-            vertexStateChanged[orderIdx] = -1;
-
-            // Examine the cycles of boundary components.
-            if (vIdx == wIdx) {
-                // Ignore this case; it implies either a one-face cone
-                // or a low degree edge, both of which should have
-                // already been picked up in the edge link tests.
-                std::cerr << "ERROR: vIdx == wIdx" << std::endl;
-            } else {
-                // We are joining two distinct tetrahedron vertices that
-                // already contribute to the same vertex link.
-                if (vertexState[vIdx].bdryEdges == 2)
-                    vtxBdryBackup(vIdx);
-                if (vertexState[wIdx].bdryEdges == 2)
-                    vtxBdryBackup(wIdx);
-
-                if (vtxBdryLength1(vIdx) && vtxBdryLength1(wIdx)) {
-                    // We are joining together two boundaries of length one.
-                    // Do nothing and mark the non-trivial genus.
-                    // std::cerr << "NON-SPHERE: 1 >-< 1" << std::endl;
-                    retVal |= VLINK_NON_SPHERE;
-                } else if (vtxBdryLength2(vIdx, wIdx)) {
-                    // We are closing off a single boundary of length two.
-                    // All good.
-                } else {
-                    vtxBdryNext(vIdx, face.tet, v, face.face, vNext, vTwist);
-                    vtxBdryNext(wIdx, adj.tet, w, adj.face, wNext, wTwist);
-
-                    if (vNext[0] == wIdx && wNext[1 ^ vTwist[0]] == vIdx) {
-                        // We are joining two adjacent edges of the vertex link.
-                        // Simply eliminate them.
-                        vtxBdryJoin(vNext[1], 0 ^ vTwist[1],
-                            wNext[0 ^ vTwist[0]],
-                            (vTwist[0] ^ wTwist[0 ^ vTwist[0]]) ^ vTwist[1]);
-                    } else if (vNext[1] == wIdx &&
-                            wNext[0 ^ vTwist[1]] == vIdx) {
-                        // Again, joining two adjacent edges of the vertex link.
-                        vtxBdryJoin(vNext[0], 1 ^ vTwist[0],
-                            wNext[1 ^ vTwist[1]],
-                            (vTwist[1] ^ wTwist[1 ^ vTwist[1]]) ^ vTwist[0]);
-                    } else {
-                        // See if we are joining two different boundary cycles
-                        // together; if so, we have created non-trivial genus in
-                        // the vertex link.
-                        tmpIdx = vertexState[vIdx].bdryNext[0];
-                        tmpTwist = vertexState[vIdx].bdryTwist[0];
-                        while (tmpIdx != vIdx && tmpIdx != wIdx) {
-                            nextIdx = vertexState[tmpIdx].
-                                bdryNext[0 ^ tmpTwist];
-                            tmpTwist ^= vertexState[tmpIdx].
-                                bdryTwist[0 ^ tmpTwist];
-                            tmpIdx = nextIdx;
-                        }
-
-                        if (tmpIdx == vIdx) {
-                            // Different boundary cycles.
-                            // Don't touch anything; just flag a
-                            // high genus error.
-                            // std::cerr << "NON-SPHERE: (X)" << std::endl;
-                            retVal |= VLINK_NON_SPHERE;
-                        } else {
-                            // Same boundary cycle.
-                            vtxBdryJoin(vNext[0], 1 ^ vTwist[0],
-                                wNext[1 ^ hasTwist],
-                                vTwist[0] ^ (hasTwist ^ wTwist[1 ^ hasTwist]));
-                            vtxBdryJoin(vNext[1], 0 ^ vTwist[1],
-                                wNext[0 ^ hasTwist],
-                                vTwist[1] ^ (hasTwist ^ wTwist[0 ^ hasTwist]));
-                        }
-                    }
-                }
-
-                vertexState[vIdx].bdryEdges--;
-                vertexState[wIdx].bdryEdges--;
-            }
-        } else {
-            // We are joining two distinct vertices together and merging
-            // their vertex links.
-            if (vertexState[vRep].rank < vertexState[wRep].rank) {
-                // Join vRep beneath wRep.
-                vertexState[vRep].parent = wRep;
-                vertexState[vRep].twistUp = hasTwist ^ parentTwists;
-
-                vertexState[wRep].bdry = vertexState[wRep].bdry +
-                    vertexState[vRep].bdry - 2;
-                if (vertexState[wRep].bdry == 0)
-                    retVal |= VLINK_CLOSED;
-
-                vertexStateChanged[orderIdx] = vRep;
-            } else {
-                // Join wRep beneath vRep.
-                vertexState[wRep].parent = vRep;
-                vertexState[wRep].twistUp = hasTwist ^ parentTwists;
-                if (vertexState[vRep].rank == vertexState[wRep].rank) {
-                    vertexState[vRep].rank++;
-                    vertexState[wRep].hadEqualRank = true;
-                }
-
-                vertexState[vRep].bdry = vertexState[vRep].bdry +
-                    vertexState[wRep].bdry - 2;
-                if (vertexState[vRep].bdry == 0)
-                    retVal |= VLINK_CLOSED;
-
-                vertexStateChanged[orderIdx] = wRep;
-            }
-
-            nVertexClasses--;
-
-            // Adjust the cycles of boundary components.
-            if (vertexState[vIdx].bdryEdges == 2)
-                vtxBdryBackup(vIdx);
-            if (vertexState[wIdx].bdryEdges == 2)
-                vtxBdryBackup(wIdx);
-
-            if (vtxBdryLength1(vIdx)) {
-                if (vtxBdryLength1(wIdx)) {
-                    // Both vIdx and wIdx form entire boundary components of
-                    // length one; these are joined together and the vertex
-                    // link is closed off.
-                    // No changes to make for the boundary cycles.
-                } else {
-                    // Here vIdx forms a boundary component of length one,
-                    // and wIdx does not.  Ignore vIdx, and simply excise the
-                    // relevant edge from wIdx.
-                    // There is nothing to do here unless wIdx only has one
-                    // boundary edge remaining (in which case we know it
-                    // joins to some different tetrahedron vertex).
-                    if (vertexState[wIdx].bdryEdges == 1) {
-                        wNext[0] = vertexState[wIdx].bdryNext[0];
-                        wNext[1] = vertexState[wIdx].bdryNext[1];
-                        wTwist[0] = vertexState[wIdx].bdryTwist[0];
-                        wTwist[1] = vertexState[wIdx].bdryTwist[1];
-
-                        vtxBdryJoin(wNext[0], 1 ^ wTwist[0], wNext[1],
-                            wTwist[0] ^ wTwist[1]);
-                    }
-                }
-            } else if (vtxBdryLength1(wIdx)) {
-                // As above, but with the two vertices the other way around.
-                if (vertexState[vIdx].bdryEdges == 1) {
-                    vNext[0] = vertexState[vIdx].bdryNext[0];
-                    vNext[1] = vertexState[vIdx].bdryNext[1];
-                    vTwist[0] = vertexState[vIdx].bdryTwist[0];
-                    vTwist[1] = vertexState[vIdx].bdryTwist[1];
-
-                    vtxBdryJoin(vNext[0], 1 ^ vTwist[0], vNext[1],
-                        vTwist[0] ^ vTwist[1]);
-                }
-            } else {
-                // Each vertex belongs to a boundary component of length
-                // at least two.  Merge the components together.
-                vtxBdryNext(vIdx, face.tet, v, face.face, vNext, vTwist);
-                vtxBdryNext(wIdx, adj.tet, w, adj.face, wNext, wTwist);
-
-                vtxBdryJoin(vNext[0], 1 ^ vTwist[0], wNext[1 ^ hasTwist],
-                    vTwist[0] ^ (hasTwist ^ wTwist[1 ^ hasTwist]));
-                vtxBdryJoin(vNext[1], 0 ^ vTwist[1], wNext[0 ^ hasTwist],
-                    vTwist[1] ^ (hasTwist ^ wTwist[0 ^ hasTwist]));
-            }
-
-            vertexState[vIdx].bdryEdges--;
-            vertexState[wIdx].bdryEdges--;
-        }
-    }
-
-    return retVal;
-}
-
-void NClosedPrimeMinSearcher::splitVertexClasses() {
-    // Split all three vertex pairs for the current face.
-    NTetFace face = order[orderElt];
-    NTetFace adj = (*pairing)[face];
-
-    int v, w;
-    int vIdx, wIdx;
-    unsigned orderIdx;
-    int rep, subRep;
-    NPerm p = gluingPerm(face);
-    // Do everything in reverse.  This includes the loop over vertices.
-    for (v = 3; v >= 0; v--) {
-        if (v == face.face)
-            continue;
-
-        w = p[v];
-        vIdx = v + 4 * face.tet;
-        wIdx = w + 4 * adj.tet;
-        orderIdx = v + 4 * orderElt;
-
-        if (vertexStateChanged[orderIdx] < 0) {
-            for (rep = vIdx; vertexState[rep].parent >= 0;
-                    rep = vertexState[rep].parent)
-                ;
-            vertexState[rep].bdry += 2;
-        } else {
-            subRep = vertexStateChanged[orderIdx];
-            rep = vertexState[subRep].parent;
-
-            vertexState[subRep].parent = -1;
-            if (vertexState[subRep].hadEqualRank) {
-                vertexState[subRep].hadEqualRank = false;
-                vertexState[rep].rank--;
-            }
-
-            vertexState[rep].bdry = vertexState[rep].bdry + 2 -
-                vertexState[subRep].bdry;
-
-            vertexStateChanged[orderIdx] = -1;
-            nVertexClasses++;
-        }
-
-        // Restore cycles of boundary components.
-        if (vIdx == wIdx) {
-            // We did nothing during the merge; do nothing during the split.
-        } else {
-            vertexState[wIdx].bdryEdges++;
-            vertexState[vIdx].bdryEdges++;
-
-            switch (vertexState[wIdx].bdryEdges) {
-                case 3: vertexState[wIdx].bdryNext[0] =
-                            vertexState[wIdx].bdryNext[1] = wIdx;
-                        vertexState[wIdx].bdryTwist[0] =
-                            vertexState[wIdx].bdryTwist[1] = 0;
-                        break;
-
-                case 2: vtxBdryRestore(wIdx);
-                        // Fall through to the next case, so we can
-                        // adjust the neighbours.
-
-                case 1: // Nothing was changed for wIdx during the merge,
-                        // so there is nothing there to restore.
-
-                        // Adjust neighbours to point back to wIdx.
-                        vtxBdryFixAdj(wIdx);
-            }
-
-            switch (vertexState[vIdx].bdryEdges) {
-                case 3: vertexState[vIdx].bdryNext[0] =
-                            vertexState[vIdx].bdryNext[1] = vIdx;
-                        vertexState[vIdx].bdryTwist[0] =
-                            vertexState[vIdx].bdryTwist[1] = 0;
-                        break;
-
-                case 2: vtxBdryRestore(vIdx);
-                        // Fall through to the next case, so we can
-                        // adjust the neighbours.
-
-                case 1: // Nothing was changed for vIdx during the merge,
-                        // so there is nothing there to restore.
-
-                        // Adjust neighbours to point back to vIdx.
-                        vtxBdryFixAdj(vIdx);
-            }
-        }
-    }
-}
-
 int NClosedPrimeMinSearcher::mergeEdgeClasses() {
     NTetFace face = order[orderElt];
     NTetFace adj = (*pairing)[face];
@@ -1278,14 +751,15 @@ int NClosedPrimeMinSearcher::mergeEdgeClasses() {
         w2 = p[v2];
 
         // Look at the edge opposite v1-v2.
-        e = 5 - edgeNumber[v1][v2];
-        f = 5 - edgeNumber[w1][w2];
+        e = 5 - NEdge::edgeNumber[v1][v2];
+        f = 5 - NEdge::edgeNumber[w1][w2];
 
         orderIdx = v2 + 4 * orderElt;
 
         // We declare the natural orientation of an edge to be smaller
         // vertex to larger vertex.
-        hasTwist = (p[edgeStart[e]] > p[edgeEnd[e]] ? 1 : 0);
+        hasTwist = (p[NEdge::edgeVertex[e][0]] > p[NEdge::edgeVertex[e][1]] ?
+            1 : 0);
 
         parentTwists = 0;
         eRep = findEdgeClass(e + 6 * face.tet, parentTwists);
@@ -1394,10 +868,11 @@ int NClosedPrimeMinSearcher::mergeEdgeClasses() {
                 if (v2 == w1)
                     continue;
 
-                parentTwists = tTwist[edgeNumber[v1][w1]] ^
-                    tTwist[edgeNumber[v2][w1]];
+                parentTwists = tTwist[NEdge::edgeNumber[v1][w1]] ^
+                    tTwist[NEdge::edgeNumber[v2][w1]];
 
-                if (tRep[edgeNumber[v1][w1]] == tRep[edgeNumber[v2][w1]]) {
+                if (tRep[NEdge::edgeNumber[v1][w1]] ==
+                        tRep[NEdge::edgeNumber[v2][w1]]) {
                     hasTwist = (v1 < w1 && w1 < v2 ? 0 : 1);
                     if (hasTwist ^ parentTwists) {
                         return ECLASS_CONE;
@@ -1443,7 +918,7 @@ void NClosedPrimeMinSearcher::splitEdgeClasses() {
             continue;
 
         // Look at the edge opposite v1-v2.
-        e = 5 - edgeNumber[v1][v2];
+        e = 5 - NEdge::edgeNumber[v1][v2];
 
         eIdx = e + 6 * face.tet;
         orderIdx = v2 + 4 * orderElt;
@@ -1479,42 +954,5 @@ void NClosedPrimeMinSearcher::splitEdgeClasses() {
     }
 }
 
-void NClosedPrimeMinSearcher::vtxBdryConsistencyCheck() {
-    int adj, id, end;
-    for (id = 0; id < static_cast<int>(getNumberOfTetrahedra()) * 4; id++)
-        if (vertexState[id].bdryEdges > 0)
-            for (end = 0; end < 2; end++) {
-                adj = vertexState[id].bdryNext[end];
-                if (vertexState[adj].bdryEdges == 0)
-                    std::cerr << "CONSISTENCY ERROR: Vertex link boundary "
-                        << id << '/' << end
-                        << " runs into an internal vertex." << std::endl;
-                if (vertexState[adj].bdryNext[(1 ^ end) ^
-                        vertexState[id].bdryTwist[end]] != id)
-                    std::cerr << "CONSISTENCY ERROR: Vertex link boundary "
-                        << id << '/' << end
-                        << " has a mismatched adjacency." << std::endl;
-                if (vertexState[adj].bdryTwist[(1 ^ end) ^
-                        vertexState[id].bdryTwist[end]] !=
-                        vertexState[id].bdryTwist[end])
-                    std::cerr << "CONSISTENCY ERROR: Vertex link boundary "
-                        << id << '/' << end
-                        << " has a mismatched twist." << std::endl;
-            }
-}
-
-void NClosedPrimeMinSearcher::vtxBdryDump(std::ostream& out) {
-    for (unsigned id = 0; id < getNumberOfTetrahedra() * 4; id++) {
-        if (id > 0)
-            out << ' ';
-        out << vertexState[id].bdryNext[0]
-            << (vertexState[id].bdryTwist[0] ? '~' : '-')
-            << id
-            << (vertexState[id].bdryTwist[1] ? '~' : '-')
-            << vertexState[id].bdryNext[1];
-    }
-    out << std::endl;
-}
-
 } // namespace regina
 
