@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -97,7 +97,7 @@ unsigned long NCensus::formPartialCensus(const NFacePairing* pairing,
         census.whichPurge, NCensus::foundGluingPerms, &census);
 
     // Clean up.
-    std::for_each(autos.begin(), autos.end(), FuncDelete<NIsomorphismDirect>());
+    std::for_each(autos.begin(), autos.end(), FuncDelete<NIsomorphism>());
     return census.whichSoln - 1;
 }
 
