@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -31,7 +31,6 @@
 #include <vector>
 #include "census/nfacepairing.h"
 #include "triangulation/nfacepair.h"
-#include "triangulation/npermit.h"
 #include "triangulation/ntetrahedron.h"
 #include "triangulation/ntriangulation.h"
 #include "utilities/memutils.h"
@@ -65,10 +64,10 @@ NFacePairing::NFacePairing(const NTriangulation& tri) :
     for (index = 0, t = 0; t < nTetrahedra; t++) {
         tet = tri.getTetrahedron(t);
         for (f = 0; f < 4; f++) {
-            adj = tet->getAdjacentTetrahedron(f);
+            adj = tet->adjacentTetrahedron(f);
             if (adj) {
                 pairs[index].tet = tri.tetrahedronIndex(adj);
-                pairs[index].face = tet->getAdjacentFace(f);
+                pairs[index].face = tet->adjacentFace(f);
             } else
                 pairs[index].setBoundary(nTetrahedra);
 
@@ -85,7 +84,11 @@ std::string NFacePairing::toString() const {
             ans << " | ";
         else if (f.tet || f.face)
             ans << ' ';
-        ans << dest(f).tet << ':' << dest(f).face;
+
+        if (f.isBoundary(nTetrahedra))
+            ans << "bdry";
+        else
+            ans << dest(f).tet << ':' << dest(f).face;
     }
     return ans.str();
 }
@@ -1067,7 +1070,7 @@ void* NFacePairing::run(void* param) {
             if (isCanonicalInternal(allAutomorphisms)) {
                 args->use(this, &allAutomorphisms, args->useArgs);
                 for_each(allAutomorphisms.begin(), allAutomorphisms.end(),
-                    FuncDelete<NIsomorphismDirect>());
+                    FuncDelete<NIsomorphism>());
                 allAutomorphisms.clear();
             }
 
@@ -1158,11 +1161,11 @@ bool NFacePairing::isCanonicalInternal(NFacePairingIsoList& list) const {
     // special-case the situation in which there are no face gluings at all.
     if (isUnmatched(0, 0)) {
         // We must have just one tetrahedron with no face gluings at all.
-        NIsomorphismDirect* ans;
-        for (NPermItS4 it; ! it.done(); it++) {
-            ans = new NIsomorphismDirect(1);
+        NIsomorphism* ans;
+        for (int i = 0; i < 24 /* size of S4 */; ++i) {
+            ans = new NIsomorphism(1);
             ans->tetImage(0) = 0;
-            ans->facePerm(0) = *it;
+            ans->facePerm(0) = NPerm::S4[i];
             list.push_back(ans);
         }
         return true;
@@ -1206,8 +1209,7 @@ bool NFacePairing::isCanonicalInternal(NFacePairingIsoList& list) const {
         // If firstFace doesn't glue to the same tetrahedron but this
         // face does, we're not in canonical form.
         if (firstFaceDest.tet != 0 && firstDestPre.tet == preImage[0].tet) {
-            for_each(list.begin(), list.end(),
-                FuncDelete<NIsomorphismDirect>());
+            for_each(list.begin(), list.end(), FuncDelete<NIsomorphism>());
             list.clear();
             delete[] image;
             delete[] preImage;
@@ -1240,7 +1242,7 @@ bool NFacePairing::isCanonicalInternal(NFacePairingIsoList& list) const {
 
             if (trying.isPastEnd(nTetrahedra, true)) {
                 // We have a complete automorphism!
-                NIsomorphismDirect* ans = new NIsomorphismDirect(nTetrahedra);
+                NIsomorphism* ans = new NIsomorphism(nTetrahedra);
                 for (i = 0; i < nTetrahedra; i++) {
                     ans->tetImage(i) = image[i * 4].tet;
                     ans->facePerm(i) = NPerm(image[i * 4].face,
@@ -1279,7 +1281,7 @@ bool NFacePairing::isCanonicalInternal(NFacePairingIsoList& list) const {
                         if (isUnmatched(trying) && (! isUnmatched(pre))) {
                             // We're not in canonical form.
                             for_each(list.begin(), list.end(),
-                                FuncDelete<NIsomorphismDirect>());
+                                FuncDelete<NIsomorphism>());
                             list.clear();
                             delete[] image;
                             delete[] preImage;
@@ -1360,7 +1362,7 @@ bool NFacePairing::isCanonicalInternal(NFacePairingIsoList& list) const {
                     } else if (fPre < fImg) {
                         // Whapow, we're not in canonical form.
                         for_each(list.begin(), list.end(),
-                            FuncDelete<NIsomorphismDirect>());
+                            FuncDelete<NIsomorphism>());
                         list.clear();
                         delete[] image;
                         delete[] preImage;
