@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -60,7 +60,7 @@ class NTriangulation;
  * pairwise matching of tetrahedron faces (as described by class
  * NFacePairing) into another.
  */
-typedef std::list<NIsomorphismDirect*> NFacePairingIsoList;
+typedef std::list<NIsomorphism*> NFacePairingIsoList;
 
 /**
  * A routine used to do arbitrary processing upon a pairwise matching of
@@ -261,6 +261,10 @@ class NFacePairing : public NThread {
          * <tt>dest(n-1,3)</tt>, where <tt>n</tt> is the value of
          * <tt>getNumberOfTetrahedra()</tt>.
          *
+         * \pre This face pairing is connected, i.e., it is possible
+         * to reach any tetrahedron from any other tetrahedron via a
+         * series of matched face pairs.
+         *
          * @return \c true if and only if this face pairing is in
          * canonical form.
          */
@@ -808,6 +812,10 @@ class NFacePairing : public NThread {
          * The face pairing generation may be run in the current thread
          * or as a separate thread.
          *
+         * Because this class cannot represent an empty face pairing,
+         * if the argument \a nTetrahedra is zero then no face pairings
+         * will be generated at all.
+         *
          * \todo \optlong When generating face pairings, do some checking to
          * eliminate cases in which tetrahedron (<i>k</i> > 0) can be swapped
          * with tetrahedron 0 to produce a smaller representation of the same
@@ -864,7 +872,7 @@ class NFacePairing : public NThread {
          *
          * \pre \a newNTetrahedra is at least 1.
          *
-         * @param newTetrahedra the number of tetrahedra under
+         * @param newNTetrahedra the number of tetrahedra under
          * consideration in this new face pairing.
          */
         NFacePairing(unsigned newNTetrahedra);
@@ -953,9 +961,9 @@ class NFacePairing : public NThread {
          * of this face pairing.  If not, the given list will be left empty.
          *
          * \pre The given list is empty.
-         * \pre For each tetrahedron \a t, it is true that
-         * the sequence <tt>dest(t,0)</tt>, <tt>dest(t,1)</tt>,
-         * <tt>dest(t,2)</tt>, <tt>dest(t,3)</tt> is non-decreasing.
+         * \pre For each tetrahedron \a t, the only case in which
+         * <tt>dest(t,i)</tt> is greater than <tt>dest(t,i+1)</tt> is where
+         * faces <tt>(t,i)</tt> and <tt>(t,i+1)</tt> are paired together.
          * \pre For each tetrahedron \a t > 0, it is true that
          * <tt>dest(t,0).tet < t</tt>.
          * \pre The sequence <tt>dest(1,0)</tt>, <tt>dest(2,0)</tt>,
