@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -52,7 +52,7 @@ NTriangulation* NGluingPerms::triangulate() const {
     for (t = 0; t < nTet; t++)
         for (face = 0; face < 4; face++)
             if ((! pairing->isUnmatched(t, face)) &&
-                    (! tet[t]->getAdjacentTetrahedron(face)))
+                    (! tet[t]->adjacentTetrahedron(face)))
                 tet[t]->joinTo(face, tet[pairing->dest(t, face).tet],
                     gluingPerm(t, face));
 
@@ -67,14 +67,14 @@ int NGluingPerms::gluingToIndex(const NTetFace& source,
         const NPerm& gluing) const {
     NPerm permS3 = NPerm(pairing->dest(source).face, 3) * gluing *
         NPerm(source.face, 3);
-    return (std::find(allPermsS3, allPermsS3 + 6, permS3) - allPermsS3);
+    return (std::find(NPerm::S3, NPerm::S3 + 6, permS3) - NPerm::S3);
 }
 
 int NGluingPerms::gluingToIndex(unsigned tet, unsigned face,
         const NPerm& gluing) const {
     NPerm permS3 = NPerm(pairing->dest(tet, face).face, 3) * gluing *
         NPerm(face, 3);
-    return (std::find(allPermsS3, allPermsS3 + 6, permS3) - allPermsS3);
+    return (std::find(NPerm::S3, NPerm::S3 + 6, permS3) - NPerm::S3);
 }
 
 void NGluingPerms::dumpData(std::ostream& out) const {
