@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -42,7 +42,7 @@
 
 #include "shareableobject.h"
 #include "file/nresources.h"
-#include "utilities/nmpi.h"
+#include "maths/nlargeinteger.h"
 #include "utilities/nbooleans.h"
 
 namespace regina {
