@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -178,14 +178,14 @@ bool writeSnapPea(const char* filename, NTriangulation& tri) {
         // calls this routine with a bounded triangulation, we don't want
         // to wind up calling tetrahedronIndex(0) and crashing.
         for (i = 0; i < 4; i++)
-            if ((*it)->getAdjacentTetrahedron(i))
+            if ((*it)->adjacentTetrahedron(i))
                 out << "   " << tri.tetrahedronIndex(
-                    (*it)->getAdjacentTetrahedron(i)) << ' ';
+                    (*it)->adjacentTetrahedron(i)) << ' ';
             else
                 out << "   -1 ";
         out << '\n';
         for (i = 0; i < 4; i++)
-            out << ' ' << (*it)->getAdjacentTetrahedronGluing(i).toString();
+            out << ' ' << (*it)->adjacentGluing(i).toString();
         out << '\n';
 
         // Incident cusps.
