@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -37,7 +37,7 @@
 #endif
 
 #include "manifold/nmanifold.h"
-#include "utilities/nmatrix2.h"
+#include "maths/nmatrix2.h"
 
 namespace regina {
 
@@ -80,6 +80,8 @@ class NSFSpace;
  * The optional NManifold routine getHomologyH1() is implemented, but
  * the optional routine construct() is not.
  *
+ * \testpart
+ *
  * \todo \opt Speed up homology calculations involving orientable base
  * spaces by adding rank afterwards, instead of adding generators for
  * genus into the presentation matrix.
