@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -36,7 +36,7 @@
 #endif
 
 #include "manifold/nmanifold.h"
-#include "utilities/nmatrix2.h"
+#include "maths/nmatrix2.h"
 
 namespace regina {
 
@@ -66,6 +66,8 @@ namespace regina {
  * All optional NManifold routines except for construct() are implemented
  * for this class.
  *
+ * \testpart
+ *
  * \todo \feature Implement the == operator for finding conjugate and
  * inverse matrices.
  */
