@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -27,7 +27,8 @@
 /* end stub */
 
 /*! \file nray.h
- *  \brief Deals with rational rays rooted at the origin.
+ *  \brief Provides a slow but flexible class for rational rays rooted at
+ *  the origin.
  */
 
 #ifndef __NRAY_H
@@ -35,7 +36,7 @@
 #define __NRAY_H
 #endif
 
-#include "utilities/nmpi.h"
+#include "maths/nlargeinteger.h"
 #include "maths/nvectordense.h"
 
 namespace regina {
@@ -46,12 +47,14 @@ namespace regina {
  */
 
 /**
- * Represents a ray rooted at the origin whose coordinates are rational.
- * Such a ray is a half-line beginning at the origin and is
- * represented by a point it passes through whose coordinates are
- * all integers.
+ * A slow but flexible class storing a ray rooted at the origin whose
+ * coordinates are rational.  Such a ray is a half-line beginning at
+ * the origin and is represented by an integer point that it passes through.
+ * Positive scalar multiples of a ray are considered to represent the same ray.
  *
- * Note that scalar multiples of a ray in fact represent the same ray.
+ * Like its parent class NVector, this ray class is slow (in
+ * particular, many functions are virtual).  For a fast ray class better
+ * suited to heavy computation, see NFastRay instead.
  * 
  * \warning Subclasses of NRay \b must override clone() to return a
  * ray of the correct subclass!  Otherwise the vectors returned by
