@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -36,8 +36,8 @@
 #define __NBLOCKEDSFSPAIR_H
 #endif
 
+#include "maths/nmatrix2.h"
 #include "subcomplex/nstandardtri.h"
-#include "utilities/nmatrix2.h"
 
 namespace regina {
 
@@ -89,6 +89,8 @@ class NSatRegion;
  *
  * The optional NStandardTriangulation routine getManifold() is
  * implemented for this class, but getHomologyH1() is not.
+ *
+ * \testpart
  */
 class NBlockedSFSPair : public NStandardTriangulation {
     private:
