@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -68,10 +68,10 @@ NL31Pillow* NL31Pillow::isL31Pillow(const NComponent* comp) {
     tet[0] = comp->getTetrahedron(0);
     tet[1] = comp->getTetrahedron(1);
 
-    if (tet[0]->getAdjacentTetrahedron(0) != tet[1] ||
-            tet[0]->getAdjacentTetrahedron(1) != tet[1] ||
-            tet[0]->getAdjacentTetrahedron(2) != tet[1] ||
-            tet[0]->getAdjacentTetrahedron(3) != tet[1])
+    if (tet[0]->adjacentTetrahedron(0) != tet[1] ||
+            tet[0]->adjacentTetrahedron(1) != tet[1] ||
+            tet[0]->adjacentTetrahedron(2) != tet[1] ||
+            tet[0]->adjacentTetrahedron(3) != tet[1])
         return 0;
 
     // At this point we can prove through enumeration of all
