@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -64,7 +64,7 @@ NLayeredLensSpace* NLayeredLensSpace::isLayeredLensSpace(
             NTetrahedron* tet = torus->getTopLevel();
             int tf0 = torus->getTopFace(0);
             int tf1 = torus->getTopFace(1);
-            if (tet->getAdjacentTetrahedron(tf0) != tet) {
+            if (tet->adjacentTetrahedron(tf0) != tet) {
                 delete torus;
                 return 0;
             }
@@ -80,15 +80,15 @@ NLayeredLensSpace* NLayeredLensSpace::isLayeredLensSpace(
             NLayeredLensSpace* ans = new NLayeredLensSpace();
             ans->torus = torus;
 
-            NPerm perm = tet->getAdjacentTetrahedronGluing(tf0);
+            NPerm perm = tet->adjacentGluing(tf0);
             if (perm[tf1] == tf0) {
                 // Snapped shut.
                 ans->mobiusBoundaryGroup = torus->getTopEdgeGroup(
-                    5 - edgeNumber[tf0][tf1]);
+                    5 - NEdge::edgeNumber[tf0][tf1]);
             } else {
                 // Twisted shut.
                 ans->mobiusBoundaryGroup = torus->getTopEdgeGroup(
-                    edgeNumber[perm[tf1]][tf0]);
+                    NEdge::edgeNumber[perm[tf1]][tf0]);
             }
 
             // Work out p and q.
