@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -69,18 +69,18 @@ void NLayeredSolidTorus::transform(const NTriangulation* originalTri,
 
     // Transform edge numbers (note that -1s can also be present for topEdge[]):
     for (i = 0; i < 6; i++)
-        baseEdge[i] = edgeNumber
-            [iso->facePerm(baseTetID)[edgeStart[baseEdge[i]]]]
-            [iso->facePerm(baseTetID)[edgeEnd[baseEdge[i]]]];
+        baseEdge[i] = NEdge::edgeNumber
+            [iso->facePerm(baseTetID)[NEdge::edgeVertex[baseEdge[i]][0]]]
+            [iso->facePerm(baseTetID)[NEdge::edgeVertex[baseEdge[i]][1]]];
 
     for (i = 0; i < 3; i++)
         for (j = 0; j < 2; j++) {
             if (topEdge[i][j] < 0)
                 continue;
 
-            topEdge[i][j] = edgeNumber
-                [iso->facePerm(topTetID)[edgeStart[topEdge[i][j]]]]
-                [iso->facePerm(topTetID)[edgeEnd[topEdge[i][j]]]];
+            topEdge[i][j] = NEdge::edgeNumber
+                [iso->facePerm(topTetID)[NEdge::edgeVertex[topEdge[i][j]][0]]]
+                [iso->facePerm(topTetID)[NEdge::edgeVertex[topEdge[i][j]][1]]];
         }
 
     // Inverse arrays for edge numbers:
@@ -115,10 +115,10 @@ NLayeredSolidTorus* NLayeredSolidTorus::formsLayeredSolidTorusBase(
     bool okay;
     int i, j;
     for (baseFace1 = 0; baseFace1 < 3; baseFace1++)
-        if (tet->getAdjacentTetrahedron(baseFace1) == tet) {
+        if (tet->adjacentTetrahedron(baseFace1) == tet) {
             // This tetrahedron is glued to itself.
-            baseFace2 = tet->getAdjacentFace(baseFace1);
-            basePerm = tet->getAdjacentTetrahedronGluing(baseFace1);
+            baseFace2 = tet->adjacentFace(baseFace1);
+            basePerm = tet->adjacentGluing(baseFace1);
             okay = true;
             for (i = 0; i < 4; i++) {
                 if (i == baseFace1 || i == baseFace2)
@@ -147,12 +147,12 @@ NLayeredSolidTorus* NLayeredSolidTorus::formsLayeredSolidTorusBase(
     ans->baseFace[1] = baseFace2;
     ans->topFace[0] = basePerm[baseFace2];
     ans->topFace[1] = basePerm[ans->topFace[0]];
-    ans->baseEdge[0] = edgeNumber[baseFace1][baseFace2];
-    ans->baseEdge[1] = edgeNumber[ans->topFace[1]][baseFace2];
-    ans->baseEdge[2] = edgeNumber[ans->topFace[0]][baseFace1];
-    ans->baseEdge[3] = edgeNumber[ans->topFace[0]][baseFace2];
-    ans->baseEdge[4] = edgeNumber[ans->topFace[0]][ans->topFace[1]];
-    ans->baseEdge[5] = edgeNumber[ans->topFace[1]][baseFace1];
+    ans->baseEdge[0] = NEdge::edgeNumber[baseFace1][baseFace2];
+    ans->baseEdge[1] = NEdge::edgeNumber[ans->topFace[1]][baseFace2];
+    ans->baseEdge[2] = NEdge::edgeNumber[ans->topFace[0]][baseFace1];
+    ans->baseEdge[3] = NEdge::edgeNumber[ans->topFace[0]][baseFace2];
+    ans->baseEdge[4] = NEdge::edgeNumber[ans->topFace[0]][ans->topFace[1]];
+    ans->baseEdge[5] = NEdge::edgeNumber[ans->topFace[1]][baseFace1];
     for (i = 0; i < 6; i++)
         ans->baseEdgeGroup[ans->baseEdge[i]] = (i == 0 ? 1 : i < 3 ? 2 : 3);
 
@@ -182,31 +182,33 @@ NLayeredSolidTorus* NLayeredSolidTorus::formsLayeredSolidTorusBase(
     int layerOnGroup;
     while (true) {
         // Is there a new layer?
-        tet = ans->topLevel->getAdjacentTetrahedron(ans->topFace[0]);
+        tet = ans->topLevel->adjacentTetrahedron(ans->topFace[0]);
         if (tet == 0 || tet == ans->topLevel ||
-                tet != ans->topLevel->getAdjacentTetrahedron(ans->topFace[1]))
+                tet != ans->topLevel->adjacentTetrahedron(ans->topFace[1]))
             break;
 
         // There is a new tetrahedron glued to both torus boundary faces.
-        adjPerm[0] = ans->topLevel->getAdjacentTetrahedronGluing(
+        adjPerm[0] = ans->topLevel->adjacentGluing(
             ans->topFace[0]);
-        adjPerm[1] = ans->topLevel->getAdjacentTetrahedronGluing(
+        adjPerm[1] = ans->topLevel->adjacentGluing(
             ans->topFace[1]);
         if (adjPerm[0].sign() != adjPerm[1].sign())
             break;
 
         // See what the new boundary edge would be.
-        adjFace[0] = ans->topLevel->getAdjacentFace(ans->topFace[0]);
-        adjFace[1] = ans->topLevel->getAdjacentFace(ans->topFace[1]);
-        newTopEdge = edgeNumber[adjFace[0]][adjFace[1]];
+        adjFace[0] = ans->topLevel->adjacentFace(ans->topFace[0]);
+        adjFace[1] = ans->topLevel->adjacentFace(ans->topFace[1]);
+        newTopEdge = NEdge::edgeNumber[adjFace[0]][adjFace[1]];
         adjEdge = 5 - newTopEdge;
 
         // See which edges of the current top tetrahedron are being
         // layered upon.
-        layerOnEdge[0] = edgeNumber[adjPerm[0].preImageOf(edgeStart[adjEdge])]
-                                   [adjPerm[0].preImageOf(edgeEnd[adjEdge])];
-        layerOnEdge[1] = edgeNumber[adjPerm[1].preImageOf(edgeStart[adjEdge])]
-                                   [adjPerm[1].preImageOf(edgeEnd[adjEdge])];
+        layerOnEdge[0] = NEdge::edgeNumber
+            [adjPerm[0].preImageOf(NEdge::edgeVertex[adjEdge][0])]
+            [adjPerm[0].preImageOf(NEdge::edgeVertex[adjEdge][1])];
+        layerOnEdge[1] = NEdge::edgeNumber
+            [adjPerm[1].preImageOf(NEdge::edgeVertex[adjEdge][0])]
+            [adjPerm[1].preImageOf(NEdge::edgeVertex[adjEdge][1])];
         if (layerOnEdge[0] != layerOnEdge[1] &&
                 layerOnEdge[0] + layerOnEdge[1] != 5)
             break;
@@ -263,14 +265,15 @@ NLayeredSolidTorus* NLayeredSolidTorus::formsLayeredSolidTorusBase(
                 break;
         }
 
-        ans->topFace[0] = edgeStart[adjEdge];
-        ans->topFace[1] = edgeEnd[adjEdge];
+        ans->topFace[0] = NEdge::edgeVertex[adjEdge][0];
+        ans->topFace[1] = NEdge::edgeVertex[adjEdge][1];
 
         // Massage the indices in topEdge to match topFace.
         for (i = 0; i < 3; i++) {
             // Make sure ans->topEdge[i][0] is in face ans->topFace[0].
-            if (ans->topFace[0] == edgeStart[ans->topEdge[i][0]] ||
-                    ans->topFace[0] == edgeEnd[ans->topEdge[i][0]]) {
+            if (ans->topFace[0] == NEdge::edgeVertex[ans->topEdge[i][0]][0] ||
+                    ans->topFace[0] ==
+                    NEdge::edgeVertex[ans->topEdge[i][0]][1]) {
                 j = ans->topEdge[i][0];
                 ans->topEdge[i][0] = ans->topEdge[i][1];
                 ans->topEdge[i][1] = j;
@@ -327,15 +330,15 @@ NLayeredSolidTorus* NLayeredSolidTorus::formsLayeredSolidTorusTop(
 
         // Verify that both new faces go to the same tetrahedron (which
         // exists).
-        next = tet->getAdjacentTetrahedron(vRoles[0]);
+        next = tet->adjacentTetrahedron(vRoles[0]);
         if (! next)
             return 0;
-        if (next != tet->getAdjacentTetrahedron(vRoles[3]))
+        if (next != tet->adjacentTetrahedron(vRoles[3]))
             return 0;
 
         // Are we folding over?
-        cross1 = tet->getAdjacentTetrahedronGluing(vRoles[0]);
-        cross2 = tet->getAdjacentTetrahedronGluing(vRoles[3]);
+        cross1 = tet->adjacentGluing(vRoles[0]);
+        cross2 = tet->adjacentGluing(vRoles[3]);
         if (next == tet && cross1[vRoles[0]] == vRoles[3]) {
             // Could be.  Certainly faces vRoles[0,3] are joined to
             // each other.  This is our final iteration -- either it
@@ -369,21 +372,21 @@ NLayeredSolidTorus* NLayeredSolidTorus::formsLayeredSolidTorusTop(
             ans->base = tet;
             ans->baseFace[0] = vRoles[3]; // Face vRoles[012]
             ans->baseFace[1] = vRoles[0]; // Face vRoles[123]
-            ans->baseEdge[0] = edgeNumber[vRoles[0]][vRoles[3]];
+            ans->baseEdge[0] = NEdge::edgeNumber[vRoles[0]][vRoles[3]];
             if (rotation == 1) {
-                ans->baseEdge[1] = edgeNumber[vRoles[0]][vRoles[2]];
-                ans->baseEdge[2] = edgeNumber[vRoles[1]][vRoles[3]];
+                ans->baseEdge[1] = NEdge::edgeNumber[vRoles[0]][vRoles[2]];
+                ans->baseEdge[2] = NEdge::edgeNumber[vRoles[1]][vRoles[3]];
 
-                ans->baseEdge[3] = edgeNumber[vRoles[0]][vRoles[1]];
-                ans->baseEdge[4] = edgeNumber[vRoles[1]][vRoles[2]];
-                ans->baseEdge[5] = edgeNumber[vRoles[2]][vRoles[3]];
+                ans->baseEdge[3] = NEdge::edgeNumber[vRoles[0]][vRoles[1]];
+                ans->baseEdge[4] = NEdge::edgeNumber[vRoles[1]][vRoles[2]];
+                ans->baseEdge[5] = NEdge::edgeNumber[vRoles[2]][vRoles[3]];
             } else {
-                ans->baseEdge[1] = edgeNumber[vRoles[0]][vRoles[1]];
-                ans->baseEdge[2] = edgeNumber[vRoles[2]][vRoles[3]];
+                ans->baseEdge[1] = NEdge::edgeNumber[vRoles[0]][vRoles[1]];
+                ans->baseEdge[2] = NEdge::edgeNumber[vRoles[2]][vRoles[3]];
 
-                ans->baseEdge[3] = edgeNumber[vRoles[0]][vRoles[2]];
-                ans->baseEdge[4] = edgeNumber[vRoles[2]][vRoles[1]];
-                ans->baseEdge[5] = edgeNumber[vRoles[1]][vRoles[3]];
+                ans->baseEdge[3] = NEdge::edgeNumber[vRoles[0]][vRoles[2]];
+                ans->baseEdge[4] = NEdge::edgeNumber[vRoles[2]][vRoles[1]];
+                ans->baseEdge[5] = NEdge::edgeNumber[vRoles[1]][vRoles[3]];
             }
             ans->baseEdgeGroup[ans->baseEdge[0]] = 1;
             ans->baseEdgeGroup[ans->baseEdge[1]] = 2;
@@ -442,18 +445,28 @@ NLayeredSolidTorus* NLayeredSolidTorus::formsLayeredSolidTorusTop(
             ans->meridinalCuts[group01] = cuts01;
             ans->meridinalCuts[group13] = cuts13;
             ans->meridinalCuts[group30] = cuts30;
-            ans->topEdge[group01][0] = edgeNumber[topRoles[0]][topRoles[1]];
-            ans->topEdge[group01][1] = edgeNumber[topRoles[2]][topRoles[3]];
-            ans->topEdge[group13][0] = edgeNumber[topRoles[1]][topRoles[3]];
-            ans->topEdge[group13][1] = edgeNumber[topRoles[0]][topRoles[2]];
-            ans->topEdge[group30][0] = edgeNumber[topRoles[3]][topRoles[0]];
+            ans->topEdge[group01][0] =
+                NEdge::edgeNumber[topRoles[0]][topRoles[1]];
+            ans->topEdge[group01][1] =
+                NEdge::edgeNumber[topRoles[2]][topRoles[3]];
+            ans->topEdge[group13][0] =
+                NEdge::edgeNumber[topRoles[1]][topRoles[3]];
+            ans->topEdge[group13][1] =
+                NEdge::edgeNumber[topRoles[0]][topRoles[2]];
+            ans->topEdge[group30][0] =
+                NEdge::edgeNumber[topRoles[3]][topRoles[0]];
             ans->topEdge[group30][1] = -1;
-            ans->topEdgeGroup[edgeNumber[topRoles[0]][topRoles[1]]] = group01;
-            ans->topEdgeGroup[edgeNumber[topRoles[2]][topRoles[3]]] = group01;
-            ans->topEdgeGroup[edgeNumber[topRoles[1]][topRoles[3]]] = group13;
-            ans->topEdgeGroup[edgeNumber[topRoles[0]][topRoles[2]]] = group13;
-            ans->topEdgeGroup[edgeNumber[topRoles[3]][topRoles[0]]] = group30;
-            ans->topEdgeGroup[edgeNumber[topRoles[1]][topRoles[2]]] = -1;
+            ans->topEdgeGroup[NEdge::edgeNumber[topRoles[0]][topRoles[1]]] =
+                group01;
+            ans->topEdgeGroup[NEdge::edgeNumber[topRoles[2]][topRoles[3]]] =
+                group01;
+            ans->topEdgeGroup[NEdge::edgeNumber[topRoles[1]][topRoles[3]]] =
+                group13;
+            ans->topEdgeGroup[NEdge::edgeNumber[topRoles[0]][topRoles[2]]] =
+                group13;
+            ans->topEdgeGroup[NEdge::edgeNumber[topRoles[3]][topRoles[0]]] =
+                group30;
+            ans->topEdgeGroup[NEdge::edgeNumber[topRoles[1]][topRoles[2]]] = -1;
 
             // All done!
             return ans;
@@ -611,8 +624,8 @@ NLayeredSolidTorus* NLayeredSolidTorus::isLayeredSolidTorus(NComponent* comp) {
         // accounted for (thus showing this loop will terminate).
         // They also cannot be boundary faces, since there are only two
         // boundary faces and these have already been seen.
-        nextTet = currTet->getAdjacentTetrahedron(underFaces.lower());
-        if (nextTet != currTet->getAdjacentTetrahedron(underFaces.upper()))
+        nextTet = currTet->adjacentTetrahedron(underFaces.lower());
+        if (nextTet != currTet->adjacentTetrahedron(underFaces.upper()))
             return 0;
 
         // They both lead to the same adjacent tetrahedron.
@@ -621,8 +634,8 @@ NLayeredSolidTorus* NLayeredSolidTorus::isLayeredSolidTorus(NComponent* comp) {
             break;
 
         // No; we have simply moved on to the next tetrahedron.
-        underFaces = NFacePair(currTet->getAdjacentFace(underFaces.lower()),
-            currTet->getAdjacentFace(underFaces.upper())).complement();
+        underFaces = NFacePair(currTet->adjacentFace(underFaces.lower()),
+            currTet->adjacentFace(underFaces.upper())).complement();
         currTet = nextTet;
     }
 
@@ -636,10 +649,10 @@ void NLayeredSolidTorus::followEdge(int destGroup, int sourceGroup) {
     NPerm adjPerm;
     for (int i = 1; i >= 0; i--) {
         pos = (topEdge[sourceGroup][i] == -1 ? 0 : i);
-        adjPerm = topLevel->getAdjacentTetrahedronGluing(topFace[i]);
-        topEdge[destGroup][i] = edgeNumber
-            [adjPerm[edgeStart[topEdge[sourceGroup][pos]]]]
-            [adjPerm[edgeEnd[topEdge[sourceGroup][pos]]]];
+        adjPerm = topLevel->adjacentGluing(topFace[i]);
+        topEdge[destGroup][i] = NEdge::edgeNumber
+            [adjPerm[NEdge::edgeVertex[topEdge[sourceGroup][pos]][0]]]
+            [adjPerm[NEdge::edgeVertex[topEdge[sourceGroup][pos]][1]]];
     }
 }
 
@@ -667,8 +680,8 @@ NTriangulation* NLayeredSolidTorus::flatten(const NTriangulation* original,
     NPacket::ChangeEventBlock block(ans);
 
     // Reglue the top faces before deleting the layered solid torus.
-    NTetrahedron* adj0 = newTop->getAdjacentTetrahedron(topFace[0]);
-    NTetrahedron* adj1 = newTop->getAdjacentTetrahedron(topFace[1]);
+    NTetrahedron* adj0 = newTop->adjacentTetrahedron(topFace[0]);
+    NTetrahedron* adj1 = newTop->adjacentTetrahedron(topFace[1]);
 
     if (adj0 && adj1 && (adj0 != newTop)) {
         // A permutation for each adjacent tetrahedron.
@@ -679,9 +692,12 @@ NTriangulation* NLayeredSolidTorus::flatten(const NTriangulation* original,
 
         // Start by representing vertices of this tetrahedron instead.
         NPerm groups0 = NPerm(
-            6 - edgeStart[topEdge[0][0]] - edgeEnd[topEdge[0][0]] - topFace[0],
-            6 - edgeStart[topEdge[1][0]] - edgeEnd[topEdge[1][0]] - topFace[0],
-            6 - edgeStart[topEdge[2][0]] - edgeEnd[topEdge[2][0]] - topFace[0],
+            6 - NEdge::edgeVertex[topEdge[0][0]][0] -
+                NEdge::edgeVertex[topEdge[0][0]][1] - topFace[0],
+            6 - NEdge::edgeVertex[topEdge[1][0]][0] -
+                NEdge::edgeVertex[topEdge[1][0]][1] - topFace[0],
+            6 - NEdge::edgeVertex[topEdge[2][0]][0] -
+                NEdge::edgeVertex[topEdge[2][0]][1] - topFace[0],
             topFace[0]);
 
         NFacePair underFaces = NFacePair(topFace[0], topFace[1]).complement();
@@ -689,8 +705,8 @@ NTriangulation* NLayeredSolidTorus::flatten(const NTriangulation* original,
             NPerm(underFaces.lower(), underFaces.upper()) * groups0;
 
         // Move these to vertices of the adjacent tetrahedra.
-        groups0 = newTop->getAdjacentTetrahedronGluing(topFace[0]) * groups0;
-        groups1 = newTop->getAdjacentTetrahedronGluing(topFace[1]) * groups1;
+        groups0 = newTop->adjacentGluing(topFace[0]) * groups0;
+        groups1 = newTop->adjacentGluing(topFace[1]) * groups1;
 
         // And do the regluing.
         adj0->unjoin(groups0[3]);
@@ -710,10 +726,10 @@ NTriangulation* NLayeredSolidTorus::flatten(const NTriangulation* original,
     curr = newBase;
     currBdryFaces = NFacePair(baseFace[0], baseFace[1]).complement();
     while (curr) {
-        next = curr->getAdjacentTetrahedron(currBdryFaces.lower());
+        next = curr->adjacentTetrahedron(currBdryFaces.lower());
 
-        currBdryFaces = NFacePair(curr->getAdjacentFace(currBdryFaces.lower()),
-            curr->getAdjacentFace(currBdryFaces.upper())).complement();
+        currBdryFaces = NFacePair(curr->adjacentFace(currBdryFaces.lower()),
+            curr->adjacentFace(currBdryFaces.upper())).complement();
         delete ans->removeTetrahedron(curr);
         curr = next;
     }
