@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -36,9 +36,9 @@
 #endif
 
 #include <memory>
+#include "maths/nmatrix2.h"
 #include "subcomplex/nstandardtri.h"
 #include "triangulation/ntriangulation.h"
-#include "utilities/nmatrix2.h"
 
 namespace regina {
 
@@ -72,6 +72,8 @@ class NTxICore;
  *
  * All optional NStandardTriangulation routines are implemented for this
  * class.
+ *
+ * \testpart
  */
 class NLayeredTorusBundle : public NStandardTriangulation {
     private:
