@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -35,9 +35,9 @@
 #define __NLAYERING_H
 #endif
 
+#include "maths/nmatrix2.h"
 #include "triangulation/nperm.h"
 #include "utilities/boostutils.h"
-#include "utilities/nmatrix2.h"
 
 namespace regina {
 
