@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -63,7 +63,7 @@ NPillowTwoSphere* NPillowTwoSphere::formsPillowTwoSphere(
         }
     if (joinTo0 == -1)
         return 0;
-    
+
     // Now make sure the edges all match up and with the correct
     // permutations.
     NPerm perm = face2->getEdgeMapping(joinTo0) *
@@ -75,7 +75,7 @@ NPillowTwoSphere* NPillowTwoSphere::formsPillowTwoSphere(
                 perm * face1->getEdgeMapping(i)))
             return 0;
     }
-    
+
     // We have an answer.
     NPillowTwoSphere* ans = new NPillowTwoSphere();
     ans->face[0] = face1;
@@ -84,13 +84,5 @@ NPillowTwoSphere* NPillowTwoSphere::formsPillowTwoSphere(
     return ans;
 }
 
-void NPillowTwoSphere::reduceTriangulation() const {
-}
-
-NTriangulation* NPillowTwoSphere::getReducedTriangulation(
-        const NTriangulation* /* original */) const {
-    return 0;
-}
-
 } // namespace regina
 
