@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -182,7 +182,7 @@ NPlugTriSolidTorus* NPlugTriSolidTorus::isPlugTriSolidTorus(
 
     for (tetIndex = 0; tetIndex < nTet - 2; tetIndex++)
         for (coreIndex = 0; coreIndex < 24; coreIndex++) {
-            coreRoles[0] = allPermsS4[coreIndex];
+            coreRoles[0] = NPerm::S4[coreIndex];
             if (coreRoles[0][0] > coreRoles[0][3])
                 continue;
 
@@ -195,7 +195,7 @@ NPlugTriSolidTorus* NPlugTriSolidTorus::isPlugTriSolidTorus(
                 coreTet[i] = core->getTetrahedron(i);
                 coreRoles[i] = core->getVertexRoles(i);
                 axis[i] = coreTet[i]->getEdge(
-                    edgeNumber[coreRoles[i][0]][coreRoles[i][3]]);
+                    NEdge::edgeNumber[coreRoles[i][0]][coreRoles[i][3]]);
             }
 
             if (axis[0] == axis[1] || axis[1] == axis[2] ||
@@ -209,9 +209,9 @@ NPlugTriSolidTorus* NPlugTriSolidTorus::isPlugTriSolidTorus(
 
             // Hunt for chains.
             for (i = 0; i < 3; i++) {
-                base[0] = coreTet[(i + 1) % 3]->getAdjacentTetrahedron(
+                base[0] = coreTet[(i + 1) % 3]->adjacentTetrahedron(
                     coreRoles[(i + 1) % 3][2]);
-                base[1] = coreTet[(i + 2) % 3]->getAdjacentTetrahedron(
+                base[1] = coreTet[(i + 2) % 3]->adjacentTetrahedron(
                     coreRoles[(i + 2) % 3][1]);
                 if (base[0] != base[1]) {
                     // No chain.
@@ -221,10 +221,10 @@ NPlugTriSolidTorus* NPlugTriSolidTorus::isPlugTriSolidTorus(
 
                 // Have we layered over the major axis?
                 baseRoles[0] = coreTet[(i + 1) % 3]->
-                    getAdjacentTetrahedronGluing(coreRoles[(i + 1) % 3][2]) *
+                    adjacentGluing(coreRoles[(i + 1) % 3][2]) *
                     coreRoles[(i + 1) % 3] * NPerm(0, 3, 2, 1);
                 baseRoles[1] = coreTet[(i + 2) % 3]->
-                    getAdjacentTetrahedronGluing(coreRoles[(i + 2) % 3][1]) *
+                    adjacentGluing(coreRoles[(i + 2) % 3][1]) *
                     coreRoles[(i + 2) % 3] * NPerm(2, 1, 0, 3);
                 if (baseRoles[0] == baseRoles[1]) {
                     chainType[i] = CHAIN_MAJOR;
@@ -236,10 +236,10 @@ NPlugTriSolidTorus* NPlugTriSolidTorus::isPlugTriSolidTorus(
 
                 // Have we layered over the minor axis?
                 baseRoles[0] = coreTet[(i + 1) % 3]->
-                    getAdjacentTetrahedronGluing(coreRoles[(i + 1) % 3][2]) *
+                    adjacentGluing(coreRoles[(i + 1) % 3][2]) *
                     coreRoles[(i + 1) % 3] * NPerm(3, 0, 2, 1);
                 baseRoles[1] = coreTet[(i + 2) % 3]->
-                    getAdjacentTetrahedronGluing(coreRoles[(i + 2) % 3][1]) *
+                    adjacentGluing(coreRoles[(i + 2) % 3][1]) *
                     coreRoles[(i + 2) % 3] * NPerm(2, 1, 3, 0);
                 if (baseRoles[0] == baseRoles[1]) {
                     chainType[i] = CHAIN_MINOR;
@@ -293,32 +293,32 @@ NPlugTriSolidTorus* NPlugTriSolidTorus::isPlugTriSolidTorus(
 
             for (i = 0; i < 3; i++) {
                 if (chain[i]) {
-                    plugTet[i][0] = chain[i]->getTop()->getAdjacentTetrahedron(
+                    plugTet[i][0] = chain[i]->getTop()->adjacentTetrahedron(
                         chain[i]->getTopVertexRoles()[3]);
-                    plugTet[i][1] = chain[i]->getTop()->getAdjacentTetrahedron(
+                    plugTet[i][1] = chain[i]->getTop()->adjacentTetrahedron(
                         chain[i]->getTopVertexRoles()[0]);
                     plugRoles[i][0] = chain[i]->getTop()->
-                        getAdjacentTetrahedronGluing(chain[i]->
+                        adjacentGluing(chain[i]->
                         getTopVertexRoles()[3]) *
                         chain[i]->getTopVertexRoles() *
                         (chainType[i] == CHAIN_MAJOR ? NPerm(0, 1, 2, 3) :
                         NPerm(1, 0, 2, 3));
                     plugRoles[i][1] = chain[i]->getTop()->
-                        getAdjacentTetrahedronGluing(chain[i]->
+                        adjacentGluing(chain[i]->
                         getTopVertexRoles()[0]) *
                         chain[i]->getTopVertexRoles() *
                         (chainType[i] == CHAIN_MAJOR ? NPerm(2, 3, 1, 0) :
                         NPerm(3, 2, 1, 0));
                 } else {
                     plugTet[i][0] = coreTet[(i + 1) % 3]->
-                        getAdjacentTetrahedron(coreRoles[(i + 1) % 3][2]);
+                        adjacentTetrahedron(coreRoles[(i + 1) % 3][2]);
                     plugTet[i][1] = coreTet[(i + 2) % 3]->
-                        getAdjacentTetrahedron(coreRoles[(i + 2) % 3][1]);
+                        adjacentTetrahedron(coreRoles[(i + 2) % 3][1]);
                     plugRoles[i][0] = coreTet[(i + 1) % 3]->
-                        getAdjacentTetrahedronGluing(coreRoles[(i + 1) % 3][2])
+                        adjacentGluing(coreRoles[(i + 1) % 3][2])
                         * coreRoles[(i + 1) % 3] * NPerm(0, 3, 1, 2);
                     plugRoles[i][1] = coreTet[(i + 2) % 3]->
-                        getAdjacentTetrahedronGluing(coreRoles[(i + 2) % 3][1])
+                        adjacentGluing(coreRoles[(i + 2) % 3][1])
                         * coreRoles[(i + 2) % 3] * NPerm(0, 3, 2, 1);
                 }
             }
@@ -382,10 +382,10 @@ NPlugTriSolidTorus* NPlugTriSolidTorus::isPlugTriSolidTorus(
 
             // Finally check the internal face of the plug.
             if (! error) {
-                if (plugTet[0][0]->getAdjacentTetrahedron(realPlugRoles[0][3])
+                if (plugTet[0][0]->adjacentTetrahedron(realPlugRoles[0][3])
                         != plugTet[0][1])
                     error = true;
-                else if (plugTet[0][0]->getAdjacentTetrahedronGluing(
+                else if (plugTet[0][0]->adjacentGluing(
                         realPlugRoles[0][3]) * realPlugRoles[0] !=
                         realPlugRoles[1])
                     error = true;
