@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -26,20 +26,20 @@
 
 /* end stub */
 
+#include "maths/nmatrix2.h"
 #include "subcomplex/nsatannulus.h"
 #include "triangulation/nedge.h"
 #include "triangulation/nisomorphism.h"
 #include "triangulation/ntetrahedron.h"
 #include "triangulation/ntriangulation.h"
-#include "utilities/nmatrix2.h"
 
 namespace regina {
 
 unsigned NSatAnnulus::meetsBoundary() const {
     unsigned ans = 0;
-    if (! tet[0]->getAdjacentTetrahedron(roles[0][3]))
+    if (! tet[0]->adjacentTetrahedron(roles[0][3]))
         ans++;
-    if (! tet[1]->getAdjacentTetrahedron(roles[1][3]))
+    if (! tet[1]->adjacentTetrahedron(roles[1][3]))
         ans++;
     return ans;
 }
@@ -48,9 +48,9 @@ void NSatAnnulus::switchSides() {
     unsigned which, face;
     for (which = 0; which < 2; which++) {
         face = roles[which][3];
-        roles[which] = tet[which]->getAdjacentTetrahedronGluing(face) *
+        roles[which] = tet[which]->adjacentGluing(face) *
             roles[which];
-        tet[which] = tet[which]->getAdjacentTetrahedron(face);
+        tet[which] = tet[which]->adjacentTetrahedron(face);
     }
 }
 
@@ -159,15 +159,15 @@ bool NSatAnnulus::isJoined(const NSatAnnulus& other, NMatrix2& matching) const {
 bool NSatAnnulus::isTwoSidedTorus() const {
     // Check that the edges are identified in opposite pairs and that we
     // have no duplicates.
-    NEdge* e01 = tet[0]->getEdge(edgeNumber[roles[0][0]][roles[0][1]]);
-    NEdge* e02 = tet[0]->getEdge(edgeNumber[roles[0][0]][roles[0][2]]);
-    NEdge* e12 = tet[0]->getEdge(edgeNumber[roles[0][1]][roles[0][2]]);
+    NEdge* e01 = tet[0]->getEdge(NEdge::edgeNumber[roles[0][0]][roles[0][1]]);
+    NEdge* e02 = tet[0]->getEdge(NEdge::edgeNumber[roles[0][0]][roles[0][2]]);
+    NEdge* e12 = tet[0]->getEdge(NEdge::edgeNumber[roles[0][1]][roles[0][2]]);
 
-    if (e01 != tet[1]->getEdge(edgeNumber[roles[1][0]][roles[1][1]]))
+    if (e01 != tet[1]->getEdge(NEdge::edgeNumber[roles[1][0]][roles[1][1]]))
         return false;
-    if (e02 != tet[1]->getEdge(edgeNumber[roles[1][0]][roles[1][2]]))
+    if (e02 != tet[1]->getEdge(NEdge::edgeNumber[roles[1][0]][roles[1][2]]))
         return false;
-    if (e12 != tet[1]->getEdge(edgeNumber[roles[1][1]][roles[1][2]]))
+    if (e12 != tet[1]->getEdge(NEdge::edgeNumber[roles[1][1]][roles[1][2]]))
         return false;
 
     if (e01 == e02 || e02 == e12 || e12 == e01)
@@ -188,9 +188,9 @@ bool NSatAnnulus::isTwoSidedTorus() const {
 
         // Get mappings from tetrahedron edge roles to annulus vertex roles.
         map0 = roles[0].inverse() * tet[0]->getEdgeMapping(
-            edgeNumber[roles[0][a]][roles[0][b]]);
+            NEdge::edgeNumber[roles[0][a]][roles[0][b]]);
         map1 = roles[1].inverse() * tet[1]->getEdgeMapping(
-            edgeNumber[roles[1][a]][roles[1][b]]);
+            NEdge::edgeNumber[roles[1][a]][roles[1][b]]);
 
         // We should have {a,b} -> {a,b} and {x,y} -> {x,y} for each map.
 
