@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -337,13 +337,13 @@ void NSatRegion::calculateBaseEuler() {
         for (ann = 0; ann < it->block->nAnnuli(); ann++) {
             annData = it->block->annulus(ann);
             baseVerticesAll.insert(annData.tet[0]->getEdge(
-                edgeNumber[annData.roles[0][0]][annData.roles[0][1]]));
+                NEdge::edgeNumber[annData.roles[0][0]][annData.roles[0][1]]));
 
             if (! it->block->hasAdjacentBlock(ann)) {
                 baseVerticesBdry.insert(annData.tet[0]->getEdge(
-                    edgeNumber[annData.roles[0][0]][annData.roles[0][1]]));
+                    NEdge::edgeNumber[annData.roles[0][0]][annData.roles[0][1]]));
                 baseVerticesBdry.insert(annData.tet[1]->getEdge(
-                    edgeNumber[annData.roles[1][0]][annData.roles[1][1]]));
+                    NEdge::edgeNumber[annData.roles[1][0]][annData.roles[1][1]]));
             }
         }
 
