@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -44,14 +44,14 @@ NSnappedBall* NSnappedBall::formsSnappedBall(NTetrahedron* tet) {
     int inFace1, inFace2;
     NPerm perm;
     for (inFace1 = 0; inFace1 < 3; inFace1++)
-        if (tet->getAdjacentTetrahedron(inFace1) == tet) {
-            perm = tet->getAdjacentTetrahedronGluing(inFace1);
+        if (tet->adjacentTetrahedron(inFace1) == tet) {
+            perm = tet->adjacentGluing(inFace1);
             inFace2 = perm[inFace1];
             if (perm == NPerm(inFace1, inFace2)) {
                 // This is it!
                 NSnappedBall* ans = new NSnappedBall();
                 ans->tet = tet;
-                ans->equator = edgeNumber[inFace1][inFace2];
+                ans->equator = NEdge::edgeNumber[inFace1][inFace2];
                 return ans;
             }
         }
