@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -67,7 +67,7 @@ NSnappedTwoSphere* NSnappedTwoSphere::formsSnappedTwoSphere(
     if (ball1->getTetrahedron()->getEdge(ball1->getEquatorEdge()) !=
             ball2->getTetrahedron()->getEdge(ball2->getEquatorEdge()))
         return 0;
-    
+
     // This is it.
     NSnappedTwoSphere* ans = new NSnappedTwoSphere();
     ans->ball[0] = ball1->clone();
@@ -75,13 +75,5 @@ NSnappedTwoSphere* NSnappedTwoSphere::formsSnappedTwoSphere(
     return ans;
 }
 
-void NSnappedTwoSphere::reduceTriangulation() const {
-}
-
-NTriangulation* NSnappedTwoSphere::getReducedTriangulation(
-        const NTriangulation* /* original */) const {
-    return 0;
-}
-
 } // namespace regina
 
