@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -151,8 +151,8 @@ NSpiralSolidTorus* NSpiralSolidTorus::formsSpiralSolidTorus(NTetrahedron* tet,
 
     while (1) {
         // Examine the tetrahedron beyond tet.
-        adjTet = tet->getAdjacentTetrahedron(useVertexRoles[0]);
-        adjRoles = tet->getAdjacentTetrahedronGluing(useVertexRoles[0]) *
+        adjTet = tet->adjacentTetrahedron(useVertexRoles[0]);
+        adjRoles = tet->adjacentGluing(useVertexRoles[0]) *
             useVertexRoles * invRoleMap;
 
         // Check that we haven't hit the boundary.
