@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -78,6 +78,7 @@
     #include "surfaces/nsstandard.h"
     #include "surfaces/nsanstandard.h"
     #include "surfaces/nsquad.h"
+    #include "surfaces/nsquadoct.h"
 #else
     REGISTER_FLAVOUR(STANDARD, NNormalSurfaceVectorStandard,
         "Standard normal (tri-quad)", false, true)
@@ -85,6 +86,8 @@
         "Standard almost normal (tri-quad-oct)", true, true)
     REGISTER_FLAVOUR(QUAD, NNormalSurfaceVectorQuad,
         "Quad normal", false, true)
+    REGISTER_FLAVOUR(AN_QUAD_OCT, NNormalSurfaceVectorQuadOct,
+        "Quad-oct almost normal", true, true)
 #endif
 
 /*! \file flavourregistry.h
