@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -58,6 +58,9 @@ namespace regina {
  * Quad discs and octagonal discs are numbered outwards away from vertex 0
  * of the tetrahedron.
  *
+ * Note that, unlike NDiscType in which the meaning of NDiscType::type is
+ * flexible, the meaning of NDiscSpec::type is fixed as described above.
+ *
  * \warning This class converts the indices of normal discs of a
  * given type from NLargeInteger to <tt>unsigned long</tt>.  See the
  * precondition below.
@@ -618,6 +621,26 @@ class NDiscSpecIterator {
          * Points this iterator to the next disc, or makes it
          * past-the-end if there is no next disc.
          *
+         * Unlike most standard increment operators, this operator returns
+         * \c void.  One consequence of this is that the preincrement
+         * and postincrement operators for this class are identical.  This
+         * interface will need to be made more standard some day.
+         *
+         * \pre This iterator is not past-the-end.
+         *
+         * \ifacespython This routine is called inc(), since Python does
+         * not support the increment operator.
+         */
+        void operator++();
+        /**
+         * Points this iterator to the next disc, or makes it
+         * past-the-end if there is no next disc.
+         *
+         * Unlike most standard increment operators, this operator returns
+         * \c void.  One consequence of this is that the preincrement
+         * and postincrement operators for this class are identical.  This
+         * interface will need to be made more standard some day.
+         *
          * \pre This iterator is not past-the-end.
          *
          * \ifacespython This routine is called inc(), since Python does
@@ -721,6 +744,10 @@ inline void NDiscSpecIterator::init(const NDiscSetSurface& discSet) {
     makeValid();
 }
 
+inline void NDiscSpecIterator::operator++() {
+    current.number++;
+    makeValid();
+}
 inline void NDiscSpecIterator::operator++(int) {
     current.number++;
     makeValid();
