@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -110,7 +110,6 @@ NNormalSurface* NNormalSurface::clone() const {
     ans->connected = connected;
     ans->realBoundary = realBoundary;
     ans->compact = compact;
-    ans->canCrush = canCrush;
 
     return ans;
 }
@@ -170,8 +169,6 @@ void NNormalSurface::readIndividualProperty(NFile& infile,
         realBoundary = infile.readBool();
     else if (propType == PROPID_COMPACT)
         compact = infile.readBool();
-    else if (propType == PROPID_CANCRUSH)
-        canCrush = infile.readBool();
     else if (propType == PROPID_SURFACENAME)
         name = infile.readString();
 }
@@ -284,6 +281,100 @@ NLargeInteger NNormalSurfaceVector::isCentral(NTriangulation* triang) const {
     return tot;
 }
 
+bool NNormalSurface::isEmpty() const {
+    unsigned long nTet = triangulation->getNumberOfTetrahedra();
+    bool checkAlmostNormal = vector->allowsAlmostNormal();
+
+    unsigned long t;
+    int i;
+
+    for (t = 0; t < nTet; ++t) {
+        for (i = 0; i < 4; ++i)
+            if (getTriangleCoord(t, i) != 0)
+                return false;
+
+        for (i = 0; i < 3; ++i)
+            if (getQuadCoord(t, i) != 0)
+                return false;
+
+        if (checkAlmostNormal)
+            for (i = 0; i < 3; ++i)
+                if (getOctCoord(t, i) != 0)
+                    return false;
+    }
+
+    return true;
+}
+
+bool NNormalSurface::sameSurface(const NNormalSurface& other) const {
+    unsigned long nTet = triangulation->getNumberOfTetrahedra();
+    bool checkAlmostNormal =
+        (vector->allowsAlmostNormal() || other.vector->allowsAlmostNormal());
+
+    unsigned long t;
+    int i;
+
+    for (t = 0; t < nTet; ++t) {
+        for (i = 0; i < 4; ++i)
+            if (getTriangleCoord(t, i) != other.getTriangleCoord(t, i))
+                return false;
+
+        for (i = 0; i < 3; ++i)
+            if (getQuadCoord(t, i) != other.getQuadCoord(t, i))
+                return false;
+
+        if (checkAlmostNormal)
+            for (i = 0; i < 3; ++i)
+                if (getOctCoord(t, i) != other.getOctCoord(t, i))
+                    return false;
+    }
+
+    return true;
+}
+
+bool NNormalSurface::locallyCompatible(const NNormalSurface& other) const {
+    unsigned long nTets = triangulation->getNumberOfTetrahedra();
+
+    int type;
+    int found;
+    for (unsigned long tet = 0; tet < nTets; ++tet) {
+        found = 0;
+        for (type = 0; type < 3; ++type)
+            if (getQuadCoord(tet, type) > 0 ||
+                    other.getQuadCoord(tet, type) > 0)
+                ++found;
+        for (type = 0; type < 3; ++type)
+            if (getOctCoord(tet, type) > 0 ||
+                    other.getOctCoord(tet, type) > 0)
+                ++found;
+        if (found > 1)
+            return false;
+    }
+
+    return true;
+}
+
+void NNormalSurface::calculateOctPosition() const {
+    if (! vector->allowsAlmostNormal()) {
+        octPosition = NDiscType::NONE;
+        return;
+    }
+
+    unsigned long tetIndex;
+    int type;
+
+    for (tetIndex = 0; tetIndex < triangulation->getNumberOfTetrahedra();
+            ++tetIndex)
+        for (type = 0; type < 3; ++type)
+            if (getOctCoord(tetIndex, type) != 0) {
+                octPosition = NDiscType(tetIndex, type);
+                return;
+            }
+
+    octPosition = NDiscType::NONE;
+    return;
+}
+
 void NNormalSurface::calculateEulerCharacteristic() const {
     unsigned long index, tot;
     int type;
@@ -349,7 +440,7 @@ void NNormalSurface::calculateRealBoundary() const {
                     for (face=0; face<4; face++) {
                         if (face == type)
                             continue;
-                        if (tet->getAdjacentTetrahedron(face) == 0) {
+                        if (tet->adjacentTetrahedron(face) == 0) {
                             realBoundary = true;
                             return;
                         }
@@ -390,8 +481,6 @@ void NNormalSurface::writeXMLData(std::ostream& out) const {
         out << "\n\t" << xmlValueTag("realbdry", realBoundary.value());
     if (compact.known())
         out << "\n\t" << xmlValueTag("compact", compact.value());
-    if (canCrush.known())
-        out << "\n\t" << xmlValueTag("cancrush", canCrush.value());
 
     // Write the closing tag.
     out << " </surface>\n";
@@ -468,11 +557,6 @@ void NNormalSurface::writeToFile(NFile& out) const {
         out.writeBool(compact.value());
         out.writePropertyFooter(bookmark);
     }
-    if (canCrush.known()) {
-        bookmark = out.writePropertyHeader(PROPID_CANCRUSH);
-        out.writeBool(canCrush.value());
-        out.writePropertyFooter(bookmark);
-    }
 
     out.writeAllPropertiesFooter();
 }
@@ -488,9 +572,13 @@ NNormalSurface* NNormalSurface::readFromFile(NFile& in, int flavour,
     unsigned vecLen = in.readUInt();
     NNormalSurfaceVector* vector;
 
-    // Bring in cases from the flavour registry.
+    // Bring in cases from the flavour registry...
     #include "surfaces/flavourregistry.h"
-        return 0; // Final else statement.
+    // ... and legacy cases:
+    if (flavour == NNormalSurfaceList::AN_LEGACY)
+        vector = new NNormalSurfaceVectorANStandard(vecLen);
+    else
+        return 0;
 
     // Read all non-zero vector entries.
     int vecPos = in.readInt();
