@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -39,6 +39,7 @@
 #include "shareableobject.h"
 #include "file/nfilepropertyreader.h"
 #include "maths/nray.h"
+#include "surfaces/ndisctype.h"
 #include "triangulation/nperm.h"
 #include "utilities/nbooleans.h"
 #include "utilities/nproperty.h"
@@ -57,6 +58,10 @@ namespace regina {
  * split split the four tetrahedron vertices 0,1,2,3 into two pairs.
  * <tt>vertexSplit[i][j]</tt> is the number of the vertex split that
  * keeps vertices <tt>i</tt> and <tt>j</tt> together.
+ *
+ * It is guaranteed that vertex split \a i will keep the vertices of
+ * edge \a i together (and will therefore also keep the vertices of edge
+ * \a 5-i together).
  */
 extern const int vertexSplit[4][4];
 /**
@@ -228,7 +233,6 @@ class NXMLNormalSurfaceReader;
  *
  * \testpart
  *
- * \todo \feature Implement quad-oct space.
  * \todo \optlong Investigate using sparse vectors for storage.
  *
  * \ifacespython Not present.
@@ -264,7 +268,7 @@ class NNormalSurfaceVector : public NRay {
         /**
          * Determines if this normal surface has more than one
          * octagonal disc.  It may be assumed that at most one
-         * octagonal disc type exists in this surface.  This routine will
+         * octagonal disc \e type exists in this surface.  This routine will
          * return \c true if an octagonal type does exist and its
          * coordinate is greater than one.
          *
@@ -278,7 +282,7 @@ class NNormalSurfaceVector : public NRay {
          * routine will never be called and thus does not need to be
          * overwritten.
          *
-         * \pre At most one octagonal disc type exists in this surface.
+         * \pre At most one octagonal disc \e type exists in this surface.
          * \pre This normal surface vector is using a
          * flavour of coordinate system that allows for almost normal
          * surfaces.
@@ -558,6 +562,11 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
         std::string name;
             /**< An optional name associated with this surface. */
 
+        mutable NProperty<NDiscType> octPosition;
+            /**< The position of the first non-zero octagonal coordinate,
+                 or NDiscType::NONE if there is no non-zero octagonal
+                 coordinate.  Here NDiscType::type is an octagon type
+                 between 0 and 2 inclusive. */
         mutable NProperty<NLargeInteger> eulerChar;
             /**< The Euler characteristic of this surface. */
         mutable NProperty<NTriBool> orientable;
@@ -572,9 +581,6 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
         mutable NProperty<bool> compact;
             /**< Is this surface compact (i.e. does it only contain
              *   finitely many discs)? */
-        mutable NProperty<bool> canCrush;
-            /**< Can this surface be crushed without unintended
-                 topological side-effects? */
 
     public:
         /**
@@ -701,6 +707,28 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
         NLargeInteger getFaceArcs(unsigned long faceIndex,
             int faceVertex) const;
 
+        /**
+         * Determines the first coordinate position at which this surface
+         * has a non-zero octagonal coordinate.  In other words, if this
+         * routine returns the disc type \a t, then the octagonal
+         * coordinate returned by getOctCoord(t.tetIndex, t.type) is non-zero.
+         * Here NDiscType::type represents an octagon type within a
+         * tetrahedron, and takes values between 0 and 2 inclusive.
+         *
+         * If this surface does not contain any octagons, this routine
+         * returns NDiscType::NONE instead.
+         *
+         * This routine caches its results, which means that once it has
+         * been called for a particular surface, subsequent calls return
+         * the answer immediately.  Moreover, if the underlying coordinate
+         * system does not support almost normal surfaces, then even the
+         * first call is fast (it returns NDiscType::NONE immediately).
+         *
+         * @return the position of the first non-zero octagonal coordinate,
+         * or NDiscType::NONE if there is no such coordinate.
+         */
+        NDiscType getOctPosition() const;
+
         /**
          * Returns the number of coordinates in the specific underlying
          * coordinate system being used.
@@ -809,16 +837,29 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
         static NNormalSurface* readFromFile(NFile& in, int flavour,
             NTriangulation* triangulation);
 
+        /**
+         * Determines if this normal surface is empty (has no discs
+         * whatsoever).
+         */
+        bool isEmpty() const;
         /**
          * Determines if this normal surface is compact (has
          * finitely many discs).
          *
+         * This routine caches its results, which means that once it has
+         * been called for a particular surface, subsequent calls return
+         * the answer immediately.
+         *
          * @return \c true if and only if this normal surface is compact.
          */
         bool isCompact() const;
         /**
          * Returns the Euler characteristic of this surface.
          *
+         * This routine caches its results, which means that once it has
+         * been called for a particular surface, subsequent calls return
+         * the answer immediately.
+         *
          * \pre This normal surface is compact (has finitely many discs).
          *
          * @return the Euler characteristic.
@@ -831,8 +872,15 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
          * the result cannot be determined (for instance, if there
          * are too many normal discs).
          *
+         * This routine caches its results, which means that once it has
+         * been called for a particular surface, subsequent calls return
+         * the answer immediately.
+         *
          * \pre This normal surface is compact (has finitely many discs).
          *
+         * \todo \prob Check for absurdly large numbers of discs and bail
+         * accordingly.
+         *
          * @return true if this surface is orientable, false if this surface
          * is non-orientable and unknown if orientability cannot be
          * determined.
@@ -845,8 +893,15 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
          * the result cannot be determined (for instance, if there
          * are too many normal discs).
          *
+         * This routine caches its results, which means that once it has
+         * been called for a particular surface, subsequent calls return
+         * the answer immediately.
+         *
          * \pre This normal surface is compact (has finitely many discs).
          *
+         * \todo \prob Check for absurdly large numbers of discs and bail
+         * accordingly.
+         *
          * @return true if this surface is two-sided, false if this surface
          * is one-sided and unknown if two-sidedness cannot be determined.
          */
@@ -858,8 +913,15 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
          * the result cannot be determined (for instance, if there
          * are too many normal discs).
          *
+         * This routine caches its results, which means that once it has
+         * been called for a particular surface, subsequent calls return
+         * the answer immediately.
+         *
          * \pre This normal surface is compact (has finitely many discs).
          *
+         * \todo \prob Check for absurdly large numbers of discs and bail
+         * accordingly.
+         *
          * @return true if this surface is connected, false if this surface
          * is not connected and unknown if connectedness cannot be determined.
          */
@@ -868,6 +930,10 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
          * Determines if this surface has any real boundary, that is,
          * whether it meets any boundary faces of the triangulation.
          *
+         * This routine caches its results, which means that once it has
+         * been called for a particular surface, subsequent calls return
+         * the answer immediately.
+         *
          * @return \c true if and only if this surface has real boundary.
          */
         bool hasRealBoundary() const;
@@ -968,13 +1034,13 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
          *
          * \warning The number of tetrahedra in the new triangulation
          * can be <i>very</i> large.
-         * \warning <b>This routine has not been implemented and so
-         * currently returns an empty triangulation.</b>
          *
          * \pre This normal surface is compact and embedded.
          * \pre This normal surface contains no octagonal discs.
          *
-         * \todo \feature Implement this routine.
+         * \todo Have some error flag so we can barf politely if the
+         * resulting number of tetrahedra is going to be too large to
+         * handle.
          *
          * @return a pointer to the newly allocated resulting
          * triangulation.
@@ -1006,9 +1072,6 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
          * small Lens spaces and so on; a full list of possible changes
          * is beyond the scope of this API documentation.
          *
-         * Routine knownCanCrush() can be used to help identify whether
-         * these unintended side-effects might occur.
-         *
          * \warning This routine can have unintended topological
          * side-effects, as described above.
          * \warning In exceptional cases with non-orientable
@@ -1024,40 +1087,117 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
         NTriangulation* crush() const;
 
         /**
-         * Determines whether this surface can be crushed to a point in
-         * the associated triangulation with no unintended topological
-         * side-effects.
+         * Determines whether this and the given surface in fact
+         * represent the same normal (or almost normal) surface.
          *
-         * Note that this routine cannot determine that there \e will be
-         * unintended side-effects; it will either determine that there
-         * \e won't be unintended side-effects or it will remain
-         * inconclusive.
+         * Specifically, this routine examines (or computes) the number of
+         * normal or almost normal discs of each type, and returns \c true
+         * if and only if these counts are the same for both surfaces.
          *
-         * Unintended side-effects include any topological change other
-         * than the pure topological effects of cutting along this surface
-         * and then identifying the new boundary surface(s) to points.
+         * It does not matter what coordinate systems the two surfaces
+         * use.  In particular, it does not matter if this and the
+         * given surface use different coordinate systems, and it
+         * does not matter if one surface uses an almost normal
+         * coordinate system and the other does not.
          *
-         * These unintended side-effects can occur when the algorithm
-         * used by the crush() routine collapses pillows and footballs
-         * to obtain a proper triangulation.  Some examples of the
-         * side-effects that can occur are given in the documentation
-         * for the crush() routine.
+         * \pre Both this and the given normal surface live within the
+         * same 3-manifold triangulation.
          *
-         * \warning Currently this routine always returns \c false,
-         * i.e., an inconclusive result.  Its abilities are expected
-         * to improve with future releases.
-         *
-         * \pre This normal surface is compact and embedded.
-         * \pre This normal surface contains no octagonal discs.
-         *
-         * \todo \feature Implement this routine!  At least
-         * for embedded 2-spheres.
-         *
-         * @return \c true if this routine determines that this surface
-         * can be crushed without unintended side-effects, or \c false if
-         * this routine cannot produce a definite answer.
+         * @param other the surface to be compared with this surface.
+         * @return \c true if both surfaces represent the same normal or
+         * almost normal surface, or \c false if not.
          */
-        bool knownCanCrush() const;
+        bool sameSurface(const NNormalSurface& other) const;
+
+        /**
+         * Determines whether this and the given surface are locally compatible.
+         * Local compatibility means that, within each individual tetrahedron
+         * of the triangulation, it is possible to arrange the normal
+         * discs of both surfaces so that none intersect.
+         *
+         * This is a local constraint, not a global constraint.  That is,
+         * we do not insist that we can avoid intersections within all
+         * tetrahedra \e simultaneously.  To test the global constraint,
+         * see the (much slower) routine disjoint() instead.
+         *
+         * Local compatibility can be formulated in terms of normal disc types.
+         * Two normal (or almost normal) surfaces are locally compatible if
+         * and only if they together have at most one quadrilateral or
+         * octagonal disc type per tetrahedron.
+         *
+         * Note again that this is a local constraint only.  In particular,
+         * for almost normal surfaces, it does \e not insist that there is
+         * at most one octagonal disc type anywhere within the triangulation.
+         *
+         * If one of the two surfaces breaks the local compatibility
+         * constraints on its own (for instance, it contains two different
+         * quadrilateral disc types within the same tetrahedron), then this
+         * routine will return \c false regardless of what the other surface
+         * contains.
+         *
+         * \pre Both this and the given normal surface live within the
+         * same 3-manifold triangulation.
+         *
+         * @param other the other surface to test for local compatibility with
+         * this surface.
+         * @return \c true if the two surfaces are locally compatible, or
+         * \c false if they are not.
+         */
+        bool locallyCompatible(const NNormalSurface& other) const;
+
+        /**
+         * Determines whether this and the given surface can be placed
+         * within the surrounding triangulation so that they do not intersect
+         * anywhere at all.
+         *
+         * This is a global constraint, and therefore gives a stronger test
+         * than locallyCompatible().  However, this global constraint is
+         * also much slower to test; the running time is proportional to
+         * the total number of normal discs in both surfaces.
+         *
+         * Note that this routine has a number of preconditions.  Most
+         * importantly, it will only work if both this and the given
+         * surface use the \e same flavour of coordinate system.
+         * Running this test over two surfaces with different coordinate
+         * systems could give unpredictable results, and might
+         * crash the program entirely.
+         *
+         * \pre Both this and the given normal surface live within the
+         * same 3-manifold triangulation.
+         * \pre Both this and the given normal surface are stored using
+         * the same flavour of coordinate system (i.e., the same
+         * subclass of NNormalSurfaceVector).
+         * \pre Both this and the given surface are compact (have
+         * finitely many discs), embedded, non-empty and connected.
+         *
+         * @param other the other surface to test alongside this surface
+         * for potential intersections.
+         * @return \c true if both surfaces can be embedded without
+         * intersecting anywhere, or \c false if this and the given
+         * surface are forced to intersect at some point.
+         */
+        bool disjoint(const NNormalSurface& other) const;
+
+        /**
+         * Gives read-only access to the raw vector that sits beneath this
+         * normal surface.
+         *
+         * Generally users should not need this function.  However, it is
+         * provided here in case the need should arise (e.g., for reasons
+         * of efficiency).
+         *
+         * \warning An NNormalSurface does not know what underlying
+         * coordinate system its raw vector uses.  Unless you already know
+         * the coordinate system in advance (i.e., you created the surface
+         * yourself), it is best to keep to the coordinate-system-agnostic
+         * access functions such as NNormalSurfaceVector::getTriCoord() and
+         * NNormalSurfaceVector::getQuadCoord().
+         *
+         * \ifacespython Not present.
+         *
+         * @return the underlying raw vector.
+         */
+        const NNormalSurfaceVector* rawVector() const;
 
         /**
          * Searches for a non-vertex-linking normal 2-sphere within the
@@ -1082,42 +1222,59 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
         static NNormalSurface* findNonTrivialSphere(NTriangulation* tri);
 
         /**
-         * Searches the vertex octagonal almost normal surfaces for an
-         * almost normal 2-sphere within the given triangulation.  Only
-         * the vertex octagonal almost normal surfaces will be examined,
-         * i.e., if there is a tubed almost normal 2-sphere or a
-         * non-vertex octagonal almost normal 2-sphere then it is not
-         * guaranteed to be found.
+         * Searches the list of vertex octagonal almost normal surfaces for
+         * an almost normal 2-sphere within the given triangulation.  This
+         * means that tubed almost normal 2-spheres or non-vertex octagonal
+         * almost normal 2-spheres will not be found.
          *
-         * In some cases however (such as with closed orientable
-         * one-vertex 0-efficient triangulations), it is known that if
-         * any almost normal 2-sphere exists then an octagonal almost
-         * normal 2-sphere exists at a vertex of the solution space
-         * (and so will be found by this routine).  It is up to the caller
-         * of this routine to decide whether results such as this are
-         * applicable to the problem at hand.
+         * This search can be done either in standard almost normal
+         * coordinates (with triangles, quadrilaterals and octagons), or
+         * in quadrilateral-octagon coordinates.  This choice of coordinate
+         * system affects how we define "vertex".  The default is to use
+         * standard coordinates (where the set of vertex surfaces is larger).
          *
-         * Note that the surface returned (if any) depends upon the
-         * triangulation, and so must be destroyed before the triangulation
-         * itself.
+         * For "sufficiently nice" triangulations, if this routine fails
+         * to find an almost normal 2-sphere then we can be certain that
+         * the triangulation contains no almost normal 2-spheres at all.
+         * In particular, this is true for closed orientable one-vertex
+         * 0-efficient triangulations.  For a proof in standard coordinates,
+         * see "0-efficient triangulations of 3-manifolds", William Jaco
+         * and J. Hyam Rubinstein, J. Differential Geom. 65 (2003),
+         * no. 1, 61--168.  For a proof in quadrilateral-octagon coordinates,
+         * see "Quadrilateral-octagon coordinates for almost normal surfaces",
+         * Benjamin A. Burton, preprint, arXiv:0904.3041.
          *
-         * \warning Currently this routine is quite slow since it
+         * Note that the surface that this routine returns (if any) depends
+         * upon the triangulation, and so this surface must be destroyed
+         * before the triangulation is destroyed.
+         *
+         * \warning Currently this routine can be quite slow since it
          * performs a full enumeration of vertex almost normal surfaces.
          *
-         * \todo \opturgent Use maximisation of Euler characteristic to
+         * \todo \opt Use maximisation of Euler characteristic to
          * make this routine much faster than a plain vertex enumeration.
          *
          * @param tri the triangulation in which to search.
+         * @param quadOct \c true if we should search for vertex
+         * surfaces in quadrilateral-octagon coordiantes, or \c false
+         * (the default) if we should search for surfaces in standard
+         * almost normal coordinates.
          * @return a newly allocated vertex octagonal almost normal sphere
          * within the given triangulation, or 0 if no such sphere exists.
          */
         static NNormalSurface* findVtxOctAlmostNormalSphere(
-            NTriangulation* tri);
+            NTriangulation* tri, bool quadOct = false);
 
     protected:
         virtual void readIndividualProperty(NFile& infile,
             unsigned propType);
 
+        /**
+         * Calculates the position of the first non-zero octagon
+         * coordinate and stores it as a property.
+         */
+        void calculateOctPosition() const;
+
         /**
          * Calculates the Euler characteristic of this surface and
          * stores it as a property.
@@ -1137,13 +1294,6 @@ class NNormalSurface : public ShareableObject, public NFilePropertyReader {
          * stores the result as a property.
          */
         void calculateRealBoundary() const;
-        /**
-         * Calculates whether it can be quickly determined that this
-         * surface can be crushed to a point without unintended
-         * topological side-effects.  If conclusive, the result is
-         * stored as a property.
-         */
-        void calculateKnownCanCrush() const;
 
     friend class regina::NXMLNormalSurfaceReader;
 };
@@ -1186,6 +1336,12 @@ inline NLargeInteger NNormalSurface::getFaceArcs(unsigned long faceIndex,
     return vector->getFaceArcs(faceIndex, faceVertex, triangulation);
 }
 
+inline NDiscType NNormalSurface::getOctPosition() const {
+    if (! octPosition.known())
+        calculateOctPosition();
+    return octPosition.value();
+}
+
 inline unsigned NNormalSurface::getNumberOfCoords() const {
     return vector->size();
 }
@@ -1261,10 +1417,8 @@ inline NLargeInteger NNormalSurface::isCentral() const {
     return vector->isCentral(triangulation);
 }
 
-inline bool NNormalSurface::knownCanCrush() const {
-    if (! canCrush.known())
-        calculateKnownCanCrush();
-    return (canCrush.known() && canCrush.value());
+inline const NNormalSurfaceVector* NNormalSurface::rawVector() const {
+    return vector;
 }
 
 } // namespace regina
