@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -58,10 +58,14 @@ void NXMLNormalSurfaceReader::initialChars(const std::string& chars) {
         return;
 
     // Create a new vector and read all non-zero entries.
-    // Bring in cases from the flavour registry.
+    // Bring in cases from the flavour registry...
     NNormalSurfaceVector* vec;
     #include "surfaces/flavourregistry.h"
-        return; // Final else statement.
+    // ... and legacy cases:
+    if (flavour == NNormalSurfaceList::AN_LEGACY)
+        vec = new NNormalSurfaceVectorANStandard(vecLen);
+    else
+        return;
 
     long pos;
     NLargeInteger value;
@@ -114,10 +118,6 @@ NXMLElementReader* NXMLNormalSurfaceReader::startSubElement(
         bool val;
         if (valueOf(props.lookup("value"), val))
             surface->compact = val;
-    } else if (subTagName == "cancrush") {
-        bool val;
-        if (valueOf(props.lookup("value"), val))
-            surface->canCrush = val;
     }
     return new NXMLElementReader();
 }
