@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -90,9 +90,9 @@ NNormalSurface* NNormalSurface::findNonTrivialSphere(NTriangulation* tri) {
 }
 
 NNormalSurface* NNormalSurface::findVtxOctAlmostNormalSphere(
-        NTriangulation* tri) {
-    NNormalSurfaceList* surfaces = NNormalSurfaceList::enumerate(tri,
-        NNormalSurfaceList::AN_STANDARD);
+        NTriangulation* tri, bool quadOct) {
+    NNormalSurfaceList* surfaces = NNormalSurfaceList::enumerate(tri, quadOct ?
+        NNormalSurfaceList::AN_QUAD_OCT : NNormalSurfaceList::AN_STANDARD);
     unsigned long nSurfaces = surfaces->getNumberOfSurfaces();
     unsigned long nTets = tri->getNumberOfTetrahedra();
 
