@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -80,7 +80,7 @@ void NTriangulation::makeDoubleCover() {
                 lowerTet = tetrahedra[upperTet];
 
                 for (face = 0; face < 4; face++) {
-                    lowerAdj = lowerTet->getAdjacentTetrahedron(face);
+                    lowerAdj = lowerTet->adjacentTetrahedron(face);
 
                     // See if this tetrahedron is glued to something in the
                     // lower sheet.
@@ -89,12 +89,12 @@ void NTriangulation::makeDoubleCover() {
 
                     // Make sure we haven't already fixed this gluing in
                     // the upper sheet.
-                    if (upper[upperTet]->getAdjacentTetrahedron(face))
+                    if (upper[upperTet]->adjacentTetrahedron(face))
                         continue;
 
                     // Determine the expected orientation of the
                     // adjacent tetrahedron in the lower sheet.
-                    gluing = lowerTet->getAdjacentTetrahedronGluing(face);
+                    gluing = lowerTet->adjacentGluing(face);
                     lowerAdjOrientation = (gluing.sign() == 1 ?
                         -lowerTet->tetOrientation : lowerTet->tetOrientation);
 
