@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -65,10 +65,10 @@ unsigned long NTriangulation::splitIntoComponents(NPacket* componentParent,
     for (tetPos = 0; tetPos < nTets; tetPos++) {
         tet = tetrahedra[tetPos];
         for (face = 0; face < 4; face++) {
-            adjTet = tet->getAdjacentTetrahedron(face);
+            adjTet = tet->adjacentTetrahedron(face);
             if (adjTet) {
                 adjPos = tetrahedronIndex(adjTet);
-                adjPerm = tet->getAdjacentTetrahedronGluing(face);
+                adjPerm = tet->adjacentGluing(face);
                 if (adjPos > tetPos ||
                         (adjPos == tetPos && adjPerm[face] > face))
                     newTets[tetPos]->joinTo(face, newTets[adjPos], adjPerm);
@@ -187,17 +187,19 @@ unsigned long NTriangulation::connectedSumDecomposition(NPacket* primeParent,
                 delete sphere;
                 delete processing;
             } else {
-                // Now we have a one-vertex prime 0-efficient triangulation.
+                // Now we have a closed orientable one-vertex 0-efficient
+                // triangulation.
                 // We have to look for an almost normal sphere.
                 //
                 // From the proof of Proposition 5.12 in Jaco & Rubinstein's
                 // 0-efficiency paper, we see that we can restrict our
                 // search to octagonal almost normal surfaces.
-                // Furthermore, from Casson's proof (directly following
-                // Proposition 5.12), we see that we can restrict this
-                // search further to vertex octagonal almost normal surfaces.
+                // Furthermore, from the result in the quadrilateral-octagon
+                // coordinates paper, we can restrict this search further
+                // to vertex octagonal almost normal surfaces in
+                // quadrilateral-octagonal space.
                 sphere = NNormalSurface::findVtxOctAlmostNormalSphere(
-                    processing);
+                    processing, true /* quad-oct coordinates */);
                 if (sphere) {
                     // It's a 3-sphere.  Toss this component away.
                     delete sphere;
@@ -326,17 +328,19 @@ bool NTriangulation::isThreeSphere() const {
                 delete sphere;
                 delete processing;
             } else {
-                // Now we have a one-vertex 0-efficient triangulation.
+                // Now we have a closed orientable one-vertex 0-efficient
+                // triangulation.
                 // We have to look for an almost normal sphere.
                 //
                 // From the proof of Proposition 5.12 in Jaco & Rubinstein's
                 // 0-efficiency paper, we see that we can restrict our
                 // search to octagonal almost normal surfaces.
-                // Furthermore, from Casson's proof (directly following
-                // Proposition 5.12), we see that we can restrict this
-                // search further to vertex octagonal almost normal surfaces.
+                // Furthermore, from the result in the quadrilateral-octagon
+                // coordinates paper, we can restrict this search further
+                // to vertex octagonal almost normal surfaces in
+                // quadrilateral-octagonal space.
                 sphere = NNormalSurface::findVtxOctAlmostNormalSphere(
-                    processing);
+                    processing, true /* quad-oct coordinates */);
                 if (sphere) {
                     // It's a 3-sphere.  Toss this component away.
                     delete sphere;
@@ -370,6 +374,51 @@ bool NTriangulation::knowsThreeSphere() const {
     return false;
 }
 
+bool NTriangulation::isBall() const {
+    if (threeBall.known())
+        return threeBall.value();
+
+    // Basic property checks.
+    if (! (isValid() && hasBoundaryFaces() && isOrientable() && isConnected()
+            && boundaryComponents.size() == 1
+            && boundaryComponents.front()->getEulerCharacteristic() == 2)) {
+        threeBall = false;
+        return false;
+    }
+
+    // Pass straight to isThreeSphere (which in turn will check faster things
+    // like homology before pulling out the big guns).
+    //
+    // Cone the boundary to a point (i.e., fill it with a ball), then
+    // call isThreeSphere() on the resulting closed triangulation.
+
+    NTriangulation working(*this);
+    working.intelligentSimplify();
+    working.finiteToIdeal();
+
+    // Simplify again in case our coning was inefficient.
+    working.intelligentSimplify();
+
+    threeBall = working.isThreeSphere();
+    return threeBall.value();
+}
+
+bool NTriangulation::knowsBall() const {
+    if (threeBall.known())
+        return true;
+
+    // Run some very fast prelimiary tests before we give up and say no.
+    if (! (isValid() && hasBoundaryFaces() && isOrientable() && isConnected()
+            && boundaryComponents.size() == 1
+            && boundaryComponents.front()->getEulerCharacteristic() == 2)) {
+        threeBall = false;
+        return true;
+    }
+
+    // More work is required.
+    return false;
+}
+
 NPacket* NTriangulation::makeZeroEfficient() {
     // Extract a connected sum decomposition.
     NContainer* connSum = new NContainer();
