@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -178,7 +178,7 @@ const NAbelianGroup& NTriangulation::getHomologyH1Rel() const {
                 currEdgeEnd = currTetVertices[(faceEdge + 1) % 3];
                 // Examine the edge from vertex edgeStart to edgeEnd
                 // in tetrahedron currTet.
-                currEdge = edgeNumber[currEdgeStart][currEdgeEnd];
+                currEdge = NEdge::edgeNumber[currEdgeStart][currEdgeEnd];
                 edgeGenIndex = genIndex[edgeIndex(
                     currTet->getEdge(currEdge))];
                 if (edgeGenIndex >= 0) {
