@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -112,7 +112,7 @@ bool NTriangulation::insertRehydration(const std::string& dehydration) {
 
     while (currTet < nTet) {
         // Is this face already glued?
-        if (tet[currTet]->getAdjacentTetrahedron(currFace)) {
+        if (tet[currTet]->adjacentTetrahedron(currFace)) {
             if (currFace < 3)
                 currFace++;
             else {
@@ -151,9 +151,9 @@ bool NTriangulation::insertRehydration(const std::string& dehydration) {
                 break;
             }
 
-            adjPerm = orderedPermsS4[permIndex] * reverse;
+            adjPerm = NPerm::orderedS4[permIndex] * reverse;
 
-            if (tet[adjTet]->getAdjacentTetrahedron(adjPerm[currFace]) ||
+            if (tet[adjTet]->adjacentTetrahedron(adjPerm[currFace]) ||
                     (adjTet == currTet && adjPerm[currFace] == currFace)) {
                 broken = true;
                 break;
@@ -261,12 +261,12 @@ std::string NTriangulation::dehydrate() const {
             // These invariants are preserved because the triangulation is
             // connected.  They break when tet == nTets.
             dest = tetrahedronIndex(
-                tetrahedra[tet]->getAdjacentTetrahedron(face));
+                tetrahedra[tet]->adjacentTetrahedron(face));
 
             // Is it a gluing we've already seen from the other side?
             if (image[dest] >= 0)
                 if (image[dest] < image[tet] || (image[dest] == image[tet] &&
-                        vertexMap[tet][tetrahedra[tet]->getAdjacentFace(face)]
+                        vertexMap[tet][tetrahedra[tet]->adjacentFace(face)]
                         < vertexMap[tet][face]))
                     continue;
 
@@ -276,7 +276,7 @@ std::string NTriangulation::dehydrate() const {
                 image[dest] = nextUnused;
                 preImage[nextUnused] = dest;
                 vertexMap[dest] = vertexMap[tet] *
-                    tetrahedra[tet]->getAdjacentTetrahedronGluing(face).
+                    tetrahedra[tet]->adjacentGluing(face).
                     inverse();
                 nextUnused++;
 
@@ -287,13 +287,13 @@ std::string NTriangulation::dehydrate() const {
                 // in dehydration language.
                 destChars[currGluingPos] = LETTER(image[dest]);
                 map = vertexMap[dest] *
-                    tetrahedra[tet]->getAdjacentTetrahedronGluing(face) *
+                    tetrahedra[tet]->adjacentGluing(face) *
                     vertexMap[tet].inverse() * NPerm(3, 2, 1, 0);
                 // Just loop to find the index of the corresponding
                 // gluing permutation.  There's only 24 permutations and
                 // at most 25 tetrahedra; we'll live with it.
                 for (mapIndex = 0; mapIndex < 24; mapIndex++)
-                    if (map == orderedPermsS4[mapIndex])
+                    if (map == NPerm::orderedS4[mapIndex])
                         break;
                 permChars[currGluingPos] = LETTER(mapIndex);
 
