@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -68,7 +68,7 @@ unsigned long NTriangulation::findIsomorphisms(
     if (tetrahedra.empty()) {
         if (completeIsomorphism && ! other.tetrahedra.empty())
             return 0;
-        results.push_back(new NIsomorphismDirect(0));
+        results.push_back(new NIsomorphism(0));
         return 1;
     }
 
@@ -190,7 +190,7 @@ unsigned long NTriangulation::findIsomorphisms(
     unsigned long nComponents = components.size();
     unsigned i;
 
-    NIsomorphismDirect iso(nTetrahedra);
+    NIsomorphism iso(nTetrahedra);
     for (i = 0; i < nTetrahedra; i++)
         iso.tetImage(i) = -1;
 
@@ -229,8 +229,7 @@ unsigned long NTriangulation::findIsomorphisms(
         // startTet[comp] and startPerm[comp].
         if (comp == static_cast<long>(nComponents)) {
             // We have an isomorphism!!!
-            results.push_back(new NIsomorphismDirect(
-                static_cast<NIsomorphism&>(iso)));
+            results.push_back(new NIsomorphism(iso));
 
             if (firstOnly) {
                 delete[] whichComp;
@@ -318,7 +317,7 @@ unsigned long NTriangulation::findIsomorphisms(
 
         whichComp[startTet[comp]] = comp;
         iso.tetImage(tetIndex) = startTet[comp];
-        iso.facePerm(tetIndex) = allPermsS4[startPerm[comp]];
+        iso.facePerm(tetIndex) = NPerm::S4[startPerm[comp]];
         toProcess.push(tetIndex);
 
         broken = false;
@@ -339,11 +338,11 @@ unsigned long NTriangulation::findIsomorphisms(
             }
 
             for (face = 0; face < 4; face++) {
-                adj = tet->getAdjacentTetrahedron(face);
+                adj = tet->adjacentTetrahedron(face);
                 if (adj) {
                     // There is an adjacent source tetrahedron.
                     // Is there an adjacent destination tetrahedron?
-                    destAdj = destTet->getAdjacentTetrahedron(tetPerm[face]);
+                    destAdj = destTet->adjacentTetrahedron(tetPerm[face]);
                     if (! destAdj) {
                         broken = true;
                         break;
@@ -352,9 +351,9 @@ unsigned long NTriangulation::findIsomorphisms(
                     adjIndex = tetrahedronIndex(adj);
                     destAdjIndex = other.tetrahedronIndex(destAdj);
                     adjPerm =
-                        destTet->getAdjacentTetrahedronGluing(tetPerm[face]) *
+                        destTet->adjacentGluing(tetPerm[face]) *
                         tetPerm *
-                        tet->getAdjacentTetrahedronGluing(face).inverse();
+                        tet->adjacentGluing(face).inverse();
 
                     if (iso.tetImage(adjIndex) >= 0) {
                         // We've already decided upon an image for this
@@ -384,7 +383,7 @@ unsigned long NTriangulation::findIsomorphisms(
                     // are after a boundary complete isomorphism.
                     // There had better be no adjacent destination
                     // tetrahedron also.
-                    if (destTet->getAdjacentTetrahedron(tetPerm[face])) {
+                    if (destTet->adjacentTetrahedron(tetPerm[face])) {
                         broken = true;
                         break;
                     }
@@ -426,7 +425,8 @@ bool NTriangulation::compatibleTets(NTetrahedron* src, NTetrahedron* dest,
         NPerm p) {
     for (int edge = 0; edge < 6; edge++) {
         if (src->getEdge(edge)->getNumberOfEmbeddings() !=
-                dest->getEdge(edgeNumber[p[edgeStart[edge]]][p[edgeEnd[edge]]])
+                dest->getEdge(NEdge::edgeNumber[p[NEdge::edgeVertex[edge][0]]]
+                    [p[NEdge::edgeVertex[edge][1]]])
                 ->getNumberOfEmbeddings())
             return false;
     }
