@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -55,14 +55,18 @@ class NEdge;
  * Note that an ideal vertex constitutes a boundary component of its
  * own. 
  *
- * If a vertex link is a multiply punctured surface, the corresponding
- * boundary components meeting the vertex will not necessarily be
- * considered a single boundary component.  The vertex
- * in question will be placed in all boundary components concerned,
- * although only one of these boundary components can be considered the
- * "official" boundary component of the vertex as returned by
- * NVertex::getBoundaryComponent().  Note that a triangulation
- * containing such a vertex is invalid.
+ * We can run into some interesting cases with invalid triangulations.
+ * Suppose some vertex link is a multiply punctured surface (which makes
+ * the vertex and hence the entire triangulation invalid).  This means
+ * that different parts of the 3-manifold boundary are effectively
+ * "pinched" together.  If this happens, the different parts of the
+ * boundary that are pinched might or might not be listed as part of the
+ * same boundary component; if not then the offending vertex will be
+ * included in all of these boundary components.  Nevertheless, only one
+ * of these can be considered the "official" boundary component of the
+ * vertex as returned by NVertex::getBoundaryComponent().  This is all a
+ * bit of a mess, but then again the entire triangulation is invalid and
+ * so you almost certainly have bigger problems to deal with.
  *
  * Boundary components are highly temporary; once a triangulation
  * changes, all its boundary component objects will be deleted and new
@@ -76,31 +80,11 @@ class NBoundaryComponent : public ShareableObject, public NMarkedElement {
             /**< List of edges in the component. */
         std::vector<NVertex*> vertices;
             /**< List of vertices in the component. */
-        
+
         bool orientable;
             /**< Is this boundary component orientable? */
 
     public:
-        /**
-         * Default constructor.
-         *
-         * \ifacespython Not present.
-         */
-        NBoundaryComponent();
-
-        /**
-         * Creates a new boundary component consisting only of the given
-         * ideal vertex.
-         *
-         * \pre The given vertex is ideal as returned by NVertex::isIdeal().
-         *
-         * \ifacespython Not present.
-         *
-         * @param idealVertex the vertex to place in the new boundary
-         * component.
-         */
-        NBoundaryComponent(NVertex* idealVertex);
-
         /**
          * Default destructor.
          */
@@ -126,7 +110,7 @@ class NBoundaryComponent : public ShareableObject, public NMarkedElement {
          * @return the number of vertices.
          */
         unsigned long getNumberOfVertices() const;
-    
+
         /**
          * Returns the requested face in this boundary component.
          *
@@ -139,7 +123,7 @@ class NBoundaryComponent : public ShareableObject, public NMarkedElement {
          * @return the requested face.
          */
         NFace* getFace(unsigned long index) const;
-    
+
         /**
          * Returns the requested edge in this boundary component.
          *
@@ -152,7 +136,7 @@ class NBoundaryComponent : public ShareableObject, public NMarkedElement {
          * @return the requested edge.
          */
         NEdge* getEdge(unsigned long index) const;
-    
+
         /**
          * Returns the requested vertex in this boundary component.
          *
@@ -197,6 +181,23 @@ class NBoundaryComponent : public ShareableObject, public NMarkedElement {
 
         void writeTextShort(std::ostream& out) const;
 
+    private:
+        /**
+         * Default constructor.
+         */
+        NBoundaryComponent();
+
+        /**
+         * Creates a new boundary component consisting only of the given
+         * ideal vertex.
+         *
+         * \pre The given vertex is ideal as returned by NVertex::isIdeal().
+         *
+         * @param idealVertex the vertex to place in the new boundary
+         * component.
+         */
+        NBoundaryComponent(NVertex* idealVertex);
+
     friend class NTriangulation;
         /**< Allow access to private members. */
 };
