@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -42,5 +42,28 @@ const int edgeStart[6] =
 const int edgeEnd[6] =
     { 1, 2, 3, 2, 3, 3 };
 
+const int NEdge::edgeNumber[4][4] = {
+    { -1, 0, 1, 2 },
+    {  0,-1, 3, 4 },
+    {  1, 3,-1, 5 },
+    {  2, 4, 5,-1 }};
+
+const int NEdge::edgeVertex[6][2] = {
+    { 0, 1 },
+    { 0, 2 },
+    { 0, 3 },
+    { 1, 2 },
+    { 1, 3 },
+    { 2, 3 }};
+
+const NPerm NEdge::ordering[6] = {
+    NPerm(0, 1, 2, 3),
+    NPerm(0, 2, 3, 1),
+    NPerm(0, 3, 1, 2),
+    NPerm(1, 2, 0, 3),
+    NPerm(1, 3, 2, 0),
+    NPerm(2, 3, 0, 1)
+};
+
 } // namespace regina
 
