@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -40,6 +40,13 @@ const int NFace::HORN = 6;
 const int NFace::DUNCEHAT = 7;
 const int NFace::L31 = 8;
 
+const NPerm NFace::ordering[4] = {
+    NPerm(1, 2, 3, 0),
+    NPerm(0, 2, 3, 1),
+    NPerm(0, 1, 3, 2),
+    NPerm(0, 1, 2, 3)
+};
+
 int NFace::getType() {
     if (type)
         return type;
@@ -103,14 +110,14 @@ int NFace::getType() {
 NEdge* NFace::getEdge(int edge) const {
     NPerm p = embeddings[0]->getVertices();
     return embeddings[0]->getTetrahedron()->getEdge(
-        edgeNumber[p[(edge + 1) % 3]][p[(edge + 2) % 3]]);
+        NEdge::edgeNumber[p[(edge + 1) % 3]][p[(edge + 2) % 3]]);
 }
 
 NPerm NFace::getEdgeMapping(int edge) const {
     NPerm facePerm = embeddings[0]->getVertices();
         // Maps face -> tetrahedron
     NPerm edgePerm = embeddings[0]->getTetrahedron()->getEdgeMapping(
-        edgeNumber[facePerm[(edge + 1) % 3]][facePerm[(edge + 2) % 3]]);
+        NEdge::edgeNumber[facePerm[(edge + 1) % 3]][facePerm[(edge + 2) % 3]]);
         // Maps edge -> tetrahedron
     return NPerm(facePerm.preImageOf(edgePerm[0]),
         facePerm.preImageOf(edgePerm[1]), edge, 3);
