@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2008, Ben Burton                                   *
+ *  Copyright (c) 1999-2009, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -132,17 +132,38 @@ class NFace : public ShareableObject, public NMarkedElement {
             /**< Specifies a face with all three edges identified using
                  non-orientable gluings.  Note that this forms a spine for
                  the Lens space L(3,1). */
+
+        /**
+         * An array that maps face numbers within a tetrahedron to the
+         * canonical ordering of the individual tetrahedron vertices
+         * that form each face.
+         *
+         * This means that the vertices of face \a i in a tetrahedron
+         * are, in canonical order, <tt>ordering[i][0..2]</tt>.  As an
+         * immediate consequence, we obtain <tt>ordering[i][3] == i</tt>.
+         *
+         * This table does \e not describe the mapping from specific
+         * triangulation faces into individual tetrahedra (for that,
+         * see NTetrahedron::getFaceMapping() instead).  This table
+         * merely provides a neat and consistent way of listing the
+         * vertices of any given tetrahedron face.
+         *
+         * This lookup table replaces the deprecated routine
+         * regina::faceOrdering().
+         */
+        static const NPerm ordering[4];
+
     private:
         NFaceEmbedding* embeddings[2];
-            /**< An array of descriptors of how this face forms a part of
-                 each individual tetrahedron it belongs to.
+            /**< An array of descriptors telling how this face forms a part of
+                 each individual tetrahedron that it belongs to.
                  These embeddings will be automatically deleted when the
                  face itself is deleted. */
         int nEmbeddings;
             /**< The number of embedding descriptors stored in
                  the embeddings array. */
         NComponent* component;
-            /**< The component that this vertex is a part of. */
+            /**< The component that this face is a part of. */
         NBoundaryComponent* boundaryComponent;
             /**< The boundary component that this face is a part of,
                  or 0 if this face is internal. */
@@ -156,17 +177,6 @@ class NFace : public ShareableObject, public NMarkedElement {
                  relevant for some face types. */
 
     public:
-        /**
-         * Creates a new face and specifies it as belonging to the
-         * given triangulation component.
-         *
-         * \ifacespython Not present.
-         *
-         * @param myComponent the triangulation component to which this
-         * face belongs.
-         */
-        NFace(NComponent* myComponent);
-
         /**
          * Default destructor.
          * All embedding descriptors stored in this face will be
@@ -226,18 +236,18 @@ class NFace : public ShareableObject, public NMarkedElement {
         bool isCone();
 
         /**
-         * Returns the number of descriptors available through
-         * getEmbedding().
+         * Returns the number of descriptors available through getEmbedding().
+         * Note that this number will never be greater than two.
          *
          * @return the number of embedding descriptors.
          */
         unsigned getNumberOfEmbeddings() const;
 
         /**
-         * Returns the requested descriptor of how this face forms a
+         * Returns the requested descriptor detailing how this face forms a
          * part of a particular tetrahedron in the triangulation.
          * Note that if this face represents multiple faces of a
-         * particular tetrahedron, there will be multiple embedding
+         * particular tetrahedron, then there will be multiple embedding
          * descriptors available regarding that tetrahedron.
          *
          * @param index the index of the requested descriptor.  This
@@ -258,49 +268,48 @@ class NFace : public ShareableObject, public NMarkedElement {
          * Returns the boundary component of the triangulation to which
          * this face belongs.
          *
-         * @return the boundary component containing this face,
-         * or 0 if this face is not on the boundary of the triangulation.
+         * @return the boundary component containing this face, or 0 if this
+         * face does not lie entirely within the boundary of the triangulation.
          */
         NBoundaryComponent* getBoundaryComponent() const;
 
         /**
-         * Returns the vertex in the triangulation skeleton corresponding
+         * Returns the vertex of the triangulation that corresponds
          * to the given vertex of this face.
          *
-         * Note that face vertex \a i is opposite face edge \a i.
+         * Note that vertex \a i of a face is opposite edge \a i of the face.
          *
          * @param vertex the vertex of this face to examine.  This should
          * be 0, 1 or 2.
-         * @return the vertex of the skeleton corresponding to the
-         * requested face vertex.
+         * @return the corresponding vertex of the triangulation.
          */
         NVertex* getVertex(int vertex) const;
         /**
-         * Returns the edge of the triangulation skeleton corresponding
+         * Returns the edge of the triangulation that corresponds
          * to the given edge of this face.
          *
-         * Note that face vertex \a i is opposite face edge \a i.
+         * Note that edge \a i of a face is opposite vertex \a i of the face.
          *
          * @param edge the edge of this face to examine.  This should be
          * 0, 1 or 2.
-         * @return the edge of the skeleton corresponding to the
-         * requested face edge.
+         * @return the corresponding edge of the triangulation.
          */
         NEdge* getEdge(int edge) const;
         /**
-         * The edge in the skeleton corresponding to the requested edge
-         * of this face is examined, and a permutation mapping vertices
-         * (0,1) of the skeleton edge to the corresponding vertices of
-         * this face is returned.
+         * Examines the given edge of this face, and returns a mapping
+         * from the "canonical" vertices of the corresponding edge of
+         * the triangulation to the vertices of this face.
          *
-         * Thus for each <tt>i=0,1</tt> and each face (or tetrahedron)
-         * containing this
-         * skeleton edge, <tt>getEdgeMapping(...)[i]</tt> will refer to
-         * vertices that are all identified to each other along the
-         * skeleton edge concerned.
+         * This routine behaves much the same as
+         * NTetrahedron::getEdgeMapping(), except that it maps the edge
+         * vertices into a face, not into a pentachoron.  See
+         * NTetrahedron::getEdgeMapping() for a more detailed
+         * explanation of precisely what this mapping means.
          *
-         * The permutation returned will map 2 to the remaining face
-         * vertex (which will be parameter \a edge) and will map 3 to 3.
+         * This routine differs from NTetrahedron::getEdgeMapping() in
+         * how it handles the images of 2 and 3.  This routine will
+         * always map 2 to the remaining vertex of this face (which is
+         * equal to the argument \a edge), and will always map 3 to itself.
          *
          * @param edge the edge of this face to examine.  This should be
          * 0, 1 or 2.
@@ -311,6 +320,16 @@ class NFace : public ShareableObject, public NMarkedElement {
 
         void writeTextShort(std::ostream& out) const;
 
+    private:
+        /**
+         * Creates a new face and marks it as belonging to the
+         * given triangulation component.
+         *
+         * @param myComponent the triangulation component to which this
+         * face belongs.
+         */
+        NFace(NComponent* myComponent);
+
     friend class NTriangulation;
         /**< Allow access to private members. */
 };
